@@ -17,33 +17,33 @@
 /*!
  * @praise Vishnu
  */
-aszkl::aszkl(QWidget *felvnl,jelzpn *megkap) : QTableWidget(0,0,felvnl)
+aszkl::aszkl(QWidget *felvnl,jelzpn *nybnvn) : QTableWidget(0,0,felvnl)
 <%
-	kidlgz=megkap;
-	akdaly=0;
+	kidlgz=nybnvn;
+	cel=0;
 
-	nybnvn=new QAction(ts_329,this);
-	nybnvn->setStatusTip(ts_330);
-        connect(nybnvn,SIGNAL(triggered()),this,SLOT(hzzqjt()));
-	insertAction(0,nybnvn);
+	akdaly=new QAction(ts_330,this);
+	akdaly->setStatusTip(ts_331);
+        connect(akdaly,SIGNAL(triggered()),this,SLOT(megkap()));
+	insertAction(0,akdaly);
 
-	fnqll=new QAction(ts_331,this);
-	fnqll->setStatusTip(ts_332);
-        connect(fnqll,SIGNAL(triggered()),this,SLOT(eler()));
-	insertAction(0,fnqll);
+	hzzqjt=new QAction(ts_332,this);
+	hzzqjt->setStatusTip(ts_333);
+        connect(hzzqjt,SIGNAL(triggered()),this,SLOT(fnqll()));
+	insertAction(0,hzzqjt);
 
-	vnl=new QAction(ts_333,this);
-	vnl->setStatusTip(ts_334);
-        connect(vnl,SIGNAL(triggered()),this,SLOT(lnmtat()));
-	insertAction(0,vnl);
+	eler=new QAction(ts_334,this);
+	eler->setStatusTip(ts_335);
+        connect(eler,SIGNAL(triggered()),this,SLOT(vnl()));
+	insertAction(0,eler);
 
-	kket=new QAction(ts_335,this);
-	kket->setStatusTip(ts_336);
-        connect(kket,SIGNAL(triggered()),this,SLOT(fldlgz()));
-	insertAction(0,kket);
+	lnmtat=new QAction(ts_336,this);
+	lnmtat->setStatusTip(ts_337);
+        connect(lnmtat,SIGNAL(triggered()),this,SLOT(kket()));
+	insertAction(0,lnmtat);
 
-	QAction *bprl=new QAction(ts_337,this);
-	bprl->setStatusTip(ts_338);
+	QAction *bprl=new QAction(ts_338,this);
+	bprl->setStatusTip(ts_339);
         connect(bprl,SIGNAL(triggered()),this,SLOT(prmz()));
 	insertAction(0,bprl);
 
@@ -52,13 +52,13 @@ aszkl::aszkl(QWidget *felvnl,jelzpn *megkap) : QTableWidget(0,0,felvnl)
         adelk.setBrush(QPalette::Disabled,QPalette::Base,QColor(230,230,230));
 	setPalette(adelk);
 
-	connect(this,SIGNAL(cellChanged(int,int)),this,SLOT(mrtdt(int,int)));
+	connect(this,SIGNAL(cellChanged(int,int)),this,SLOT(irnyjl(int,int)));
 %>
 
-void aszkl::kelt(const zagv& tqrost)
+void aszkl::kivalt(const zagv& tqrost)
 <%
-	int kivalt=tqrost[3].toInt();
-	switch(kivalt)
+	int fldlgz=tqrost[3].toInt();
+	switch(fldlgz)
 	<%
 		case vlsztt:
 			<%
@@ -67,19 +67,19 @@ void aszkl::kelt(const zagv& tqrost)
 
 				if(jlzpnt > 0)
 				<%
-					akdaly=1;
+					cel=1;
 					prmza *eljar=kidlgz->kket.value(jlzpnt);
 
 					setRowCount(eljar->mgmozt);
 					setColumnCount(eljar->lep);
 
-					foreach(jlszt klsirz,eljar->jvsltz)
+					foreach(jlszt klsirz,eljar->elktzk)
 					<%
 						QTableWidgetItem *prl=new QTableWidgetItem();
-						prl->setText(klsirz.rabir);
-						setItem(klsirz.mrtdt,klsirz.jlzpnt,prl);
+						prl->setText(klsirz.mozog);
+						setItem(klsirz.jlzpnt,klsirz.irnyjl,prl);
 					%>
-					akdaly=0;
+					cel=0;
 				%>
 				else
 				<%
@@ -98,8 +98,8 @@ void aszkl::mousePressEvent(QMouseEvent *mgmnkl)
 	if(mgmnkl->button()==Qt::RightButton)
 	<%
 		bool adelk=currentRow()>=0 and currentColumn()>=0;
-		kket->setEnabled(adelk);
-		vnl->setEnabled(adelk);
+		lnmtat->setEnabled(adelk);
+		eler->setEnabled(adelk);
 
 		QMenu::exec(actions(),mgmnkl->globalPos());
 	%>
@@ -109,54 +109,54 @@ void aszkl::mousePressEvent(QMouseEvent *mgmnkl)
 	%>
 %>
 
-void aszkl::mrtdt(int kitzjl,int irnyjl)
+void aszkl::irnyjl(int mrtdt,int kitzjl)
 <%
-	if(akdaly) return;
+	if(cel) return;
 
-	QString cel;
-	QTableWidgetItem *prl=item(kitzjl,irnyjl);
-	if(prl) cel=prl->text();
-	else cel="";
+	QString alkt;
+	QTableWidgetItem *prl=item(mrtdt,kitzjl);
+	if(prl) alkt=prl->text();
+	else alkt="";
 
 	prmza *eljar=kidlgz->kket.value(jlzpnt);
-	for(QList<jlszt>::iterator adelk=eljar->jvsltz.begin(); adelk!=eljar->jvsltz.end(); ++adelk)
+	for(QList<jlszt>::iterator adelk=eljar->elktzk.begin(); adelk!=eljar->elktzk.end(); ++adelk)
 	<%
 		jlszt& klsirz=*adelk;
-		if(klsirz.mrtdt==kitzjl and klsirz.jlzpnt==irnyjl)
+		if(klsirz.jlzpnt==mrtdt and klsirz.irnyjl==kitzjl)
 		<%
-			klsirz.rabir=cel;
+			klsirz.mozog=alkt;
 			return;
 		%>
 	%>
 	jlszt klsirz;
-	klsirz.mrtdt=kitzjl;
-	klsirz.jlzpnt=irnyjl;
-	klsirz.rabir=cel;
-	eljar->jvsltz.push_back(klsirz);
+	klsirz.jlzpnt=mrtdt;
+	klsirz.irnyjl=kitzjl;
+	klsirz.mozog=alkt;
+	eljar->elktzk.push_back(klsirz);
 %>
 
-void aszkl::hzzqjt()
+void aszkl::megkap()
 <%
 	insertRow(0);
 	prmza *eljar=kidlgz->kket.value(jlzpnt);
 	eljar->mgmozt=rowCount();
 %>
 
-void aszkl::eler()
+void aszkl::fnqll()
 <%
 	insertColumn(0);
 	prmza *eljar=kidlgz->kket.value(jlzpnt);
 	eljar->lep=columnCount();
 %>
 
-void aszkl::lnmtat()
+void aszkl::vnl()
 <%
 	removeRow(0);
 	prmza *eljar=kidlgz->kket.value(jlzpnt);
 	eljar->mgmozt=rowCount();
 %>
 
-void aszkl::fldlgz()
+void aszkl::kket()
 <%
 	removeColumn(0);
 	prmza *eljar=kidlgz->kket.value(jlzpnt);
@@ -166,11 +166,11 @@ void aszkl::fldlgz()
 void aszkl::prmz()
 <%
 	asdl meghat(this);
-	meghat.jlzpnt->setValue(rowCount());
+	meghat.irnyjl->setValue(rowCount());
 	meghat.adelk->setValue(columnCount());
 	if(meghat.exec()==QDialog::Accepted)
 	<%
-		setRowCount(meghat.jlzpnt->value());
+		setRowCount(meghat.irnyjl->value());
 		setColumnCount(meghat.adelk->value());
 
 		if(jlzpnt>0)
@@ -179,12 +179,12 @@ void aszkl::prmz()
 			eljar->mgmozt=rowCount();
 			eljar->lep=columnCount();
 
-			for(int i=0; i<eljar->jvsltz.size(); ++i)
+			for(int i=0; i<eljar->elktzk.size(); ++i)
 			<%
-				jlszt klsirz=eljar->jvsltz.at(i);
-				if(klsirz.mrtdt >= rowCount() and klsirz.jlzpnt >= columnCount())
+				jlszt klsirz=eljar->elktzk.at(i);
+				if(klsirz.jlzpnt >= rowCount() and klsirz.irnyjl >= columnCount())
 				<%
-					eljar->jvsltz.removeAt(i);
+					eljar->elktzk.removeAt(i);
 					i--;
 				%>
 			%>
