@@ -12,28 +12,28 @@ class aszkl : public QTableWidget
 <%
 	Q_OBJECT
 	public:
-		aszkl(QWidget *felvnl, jelzpn *megkap);
+		aszkl(QWidget *felvnl, jelzpn *nybnvn);
 		jelzpn *kidlgz;
 
 		void mousePressEvent(QMouseEvent *mgmnkl);
 
 		int jlzpnt;
 
-		QAction *vnl;
-		QAction *kket;
-		QAction *nybnvn;
-		QAction *fnqll;
+		QAction *eler;
+		QAction *lnmtat;
+		QAction *akdaly;
+		QAction *hzzqjt;
 
-		bool akdaly;
+		bool cel;
 
 	public slots:
-		void kelt(const zagv&);
-		void lnmtat();
-		void fldlgz();
-		void hzzqjt();
-		void eler();
+		void kivalt(const zagv&);
+		void vnl();
+		void kket();
+		void megkap();
+		void fnqll();
 		void prmz();
-		void mrtdt(int kitzjl, int irnyjl);
+		void irnyjl(int mrtdt, int kitzjl);
 %>;
 
 #endif
