@@ -16,7 +16,7 @@ class egykl : public QTreeWidget
 <%
 	Q_OBJECT
 	public:
-		egykl(QWidget *felvnl, jelzpn *megkap);
+		egykl(QWidget *felvnl, jelzpn *nybnvn);
 		jelzpn *kidlgz;
 
 		QMap<int, QTreeWidgetItem*> kket;
@@ -28,7 +28,7 @@ class egykl : public QTreeWidget
 		bool kitzjl;
 
 	public slots:
-		void kelt(const zagv&);
+		void kivalt(const zagv&);
 		void vnl(const QString & lnmtat);
 		void eler();
 %>;
