@@ -15,33 +15,33 @@ class szkl : public QWidget
 <%
 	Q_OBJECT
 	public:
-		szkl(QWidget *felvnl, jelzpn *megkap);
+		szkl(QWidget *felvnl, jelzpn *nybnvn);
 		jelzpn *kidlgz;
-		KTextEdit *vnl;
-		QLineEdit *eler;
+		KTextEdit *fnqll;
+		QLineEdit *hzzqjt;
 
 		int jlzpnt;
 
-		ablkl *fnqll;
+		ablkl *akdaly;
 
-		QToolBar *irnyjl;
+		QToolBar *kitzjl;
 
-		void kitzjl(const QTextCharFormat &mrtdt);
+		void mrtdt(const QTextCharFormat &prmz);
 
+		QAction *vnl;
+		QAction *prl;
 		QAction *mgmnkl;
-		QAction *lnmtat;
-		QAction *kket;
 
 	public slots:
-		void kelt(const zagv&);
-		void hzzqjt(const QString &);
-		void nybnvn();
+		void kivalt(const zagv&);
+		void cel(const QString &);
+		void megkap();
 
-		void fldlgz();
+		void lnmtat();
+		void kket();
 		void bprl();
-		void prmz();
 
-		void prl(const QTextCharFormat&);
+		void eler(const QTextCharFormat&);
 %>;
 
 #endif
