@@ -14,16 +14,16 @@ class elgy: public QObject
 	public:
 		elgy(QObject *felvnl);
 		~elgy();
-		elgy(QObject *felvnl, QString bprl, QString sima);
+		elgy(QObject *felvnl, QString kitzjl, QString sima);
 
+		QString kket;
 		QString kidlgz;
-		QString eler;
-		QString irnyjl;
-		QSvgRenderer *adelk;
+		QString jlzpnt;
+		QSvgRenderer *irnyjl;
 
-		QSvgRenderer* prmz();
+		QSvgRenderer* bprl();
 
-		const QIcon kitzjl();
+		const QIcon prmz();
 %>;
 
 #endif
