@@ -44,73 +44,73 @@ class ablkl : public KXmlGuiWindow
 		ablkl(QWidget *felvnl=0);
 		~ablkl();
 
-		void prmz();
+		void fldlgz();
 		void kitzjl();
 
-		felu *mzgat;
-		oszk *lep;
+		felu *kapni;
+		oszk *mgzerz;
 
 		dbz *eler;
 
-		egytr *kapod;
+		egytr *prmz;
 		jelzpn *kidlgz;
 
-		nztv *kltzik;
-		egyklh *jvsltz;
+		nztv *rabir;
+		egyklh *mozog;
 		szkl *tqrost;
 		jelzlk *vnl;
 		aszkl *prl;
 
-		KAction *letsit;
+		KAction *lmzdul;
 
-		KAction *hzzqjt;
-		KAction *kivalt;
-		KAction *jlnrdz;
-		KAction *nybnvn;
+		KAction *megkap;
+		KAction *elktzk;
+		KAction *vmrgem;
+		KAction *zandek;
 		KToolBar *fnqll;
-		KToolBar *ceco;
-		KToolBar *munka;
+		KToolBar *cel;
+		KToolBar *fladat;
 
-		KMenu *megkap;
-		QAction *elodez;
-		QAction *targy;
-		QAction *fladat;
-		QAction *cel;
+		KMenu *nybnvn;
+		QAction *letsit;
+		QAction *kelt;
+		QAction *hsztzk;
+		QAction *alkt;
 
-		QActionGroup *hsztzk;
+		QActionGroup *teremt;
 
-		QActionGroup *korrkt;
+		QActionGroup *dolog;
 
-		QActionGroup *csals;
-		QAction* jo;
+		QActionGroup *akdaly;
+		QAction* hzzqjt;
 
 		KRecentFilesAction* lnmtat;
 
-		void mgmozt(const KUrl&);
+		void kapod(const KUrl&);
 
-		QString lmzdul;
+		QString mzgat;
 
 		bool queryClose();
 
 	public slots:
-		void teremt();
-		bool vmrgem();
-		bool eljar();
-		void elktzk();
+		void jvsltz();
+		bool kltzik();
+		bool lep();
+		void mgmozt();
 
 		void kket(const KUrl &);
 
-		void alkt();
-		void zandek();
-		void dolog();
-		void akdaly();
+		void kivalt();
+		void jlnrdz();
+		void elodez();
+		void targy();
 
-		void kelt();
+		void eljar();
 
-		void rabir();
+		void sima();
 
 		void mgmnkl();
-		void mozog(const QString &, int);
+		void korrkt(const QString &, int);
 %>;
 
 #endif
