@@ -18,14 +18,14 @@
 /*!
  * @praise Vishnu
  */
-egytr::egytr(QWidget *felvnl,jelzpn *megkap) : QWidget(felvnl)
+egytr::egytr(QWidget *felvnl,jelzpn *nybnvn) : QWidget(felvnl)
 <%
-	kidlgz=megkap;
-	QGridLayout *tqrost=new QGridLayout();
-	jlnrdz=new egykl(this,megkap);
+	kidlgz=nybnvn;
+	QGridLayout *fldlgz=new QGridLayout();
+	kelt=new egykl(this,nybnvn);
 
 	KPushButton *irnyjl=new KPushButton(this);
-	irnyjl->setIcon(KIcon(ts_255));
+	irnyjl->setIcon(KIcon(ts_256));
 	irnyjl->setIconSize(QSize(22,22));
 	irnyjl->setFlat(1);
 	irnyjl->setFocusPolicy(Qt::NoFocus);
@@ -36,18 +36,18 @@ egytr::egytr(QWidget *felvnl,jelzpn *megkap) : QWidget(felvnl)
 	QLineEdit *adelk=new QLineEdit(this);
 
 	connect(irnyjl,SIGNAL(clicked(bool)),adelk,SLOT(clear()));
-	connect(adelk,SIGNAL(textChanged(const QString&)),jlnrdz,SLOT(vnl(const QString&)));
+	connect(adelk,SIGNAL(textChanged(const QString&)),kelt,SLOT(vnl(const QString&)));
 
-	tqrost->addWidget(irnyjl,0,0);
-	tqrost->addWidget(adelk,0,1);
-	tqrost->addWidget(jlnrdz,1,0,1,2);
+	fldlgz->addWidget(irnyjl,0,0);
+	fldlgz->addWidget(adelk,0,1);
+	fldlgz->addWidget(kelt,1,0,1,2);
 
-	setLayout(tqrost);
+	setLayout(fldlgz);
 %>
 
-void egytr::kelt(const zagv& adelk)
+void egytr::kivalt(const zagv& adelk)
 <%
-	jlnrdz->kelt(adelk);
+	kelt->kivalt(adelk);
 %>
 
 #ifdef WAF
