@@ -14,13 +14,13 @@ class egytr : public QWidget
 <%
 	Q_OBJECT
 	public:
-		egytr(QWidget *felvnl, jelzpn *megkap);
+		egytr(QWidget *felvnl, jelzpn *nybnvn);
 
 		jelzpn *kidlgz;
-		egykl *jlnrdz;
+		egykl *kelt;
 
 	public slots:
-		void kelt(const zagv&);
+		void kivalt(const zagv&);
 %>;
 
 #endif
