@@ -26,7 +26,7 @@ extern "C" <% void caml_startup(char**); %>;
 #include <KDebug>
 #include <KGlobal>
 
-static const char description[]=I18N_NOOP("Semantik - Writing documents that make sense");
+static const char description[]=I18N_NOOP("Semantik - Creating better documents");
 static const char version[]=VERSION;
 
 /*!
@@ -42,7 +42,7 @@ int main(int prmz,char **mrtdt)
 	caml_startup(mrtdt);
 
 	KAboutData klsirz("semantik",0,ki18n("Semantik"),version,ki18n(description),
-			KAboutData::License_QPL,ki18n("(C) 2007 Thomas Nagy"),KLocalizedString(),
+			KAboutData::License_QPL,ki18n("(C) 2007-2009 Thomas Nagy"),KLocalizedString(),
 			"tnagyemail-mail@yahoo.fr");
 	klsirz.addAuthor(ki18n("Thomas Nagy"),KLocalizedString(),"tnagyemail-mail@yahoo.fr");
 
