@@ -32,13 +32,16 @@
 /*!
  * @praise Vishnu
  */
-felu::felu(QWidget *irnyjl,jelzpn *megkap) : QGraphicsView(irnyjl)
+felu::felu(QWidget *megkap,jelzpn *nybnvn) : QGraphicsView(megkap)
 <%
-	nagy=irnyjl;
+	leir=megkap;
 
-	QGraphicsScene *felvnl=new QGraphicsScene(this);
-	felvnl->setSceneRect(-400,-400,400,400);
-	setScene(felvnl);
+	kapod=new QRubberBand(QRubberBand::Rectangle,this);
+	kapod->setGeometry(QRect(0,0,0,0));
+
+	QGraphicsScene *irnyjl=new QGraphicsScene(this);
+	irnyjl->setSceneRect(-400,-400,400,400);
+	setScene(irnyjl);
 
 	setRenderHint(QPainter::Antialiasing);
 
@@ -56,75 +59,62 @@ felu::felu(QWidget *irnyjl,jelzpn *megkap) : QGraphicsView(irnyjl)
 
 	/*QMatrix k(0,1,1,0,0,0);
 	QMatrix kv(1,0,0,-1,0,0);*/
-	kidlgz=megkap;
+	kidlgz=nybnvn;
 	/*setMatrix(adelk);
 	scale(0.8,0.8);*/
 	#endif
 
-	ir=meghat;
-	megir=mgmozt;
+	fortum=meghat;
+	nagy=mgmozt;
 
-	nybnvn=0;
+	akdaly=0;
 
-	lemasl=new QGraphicsLineItem(0,scene());
-	lemasl->hide();
-	lemasl->setZValue(125);
-
-	kiallt=new QGraphicsRectItem(0,scene());
-	kiallt->hide();
-	kiallt->setZValue(125);
-
-	QPen mrtdt=QPen(QColor("#0000ff"),0.3,Qt::SolidLine);
-	kiallt->setPen(mrtdt);
-
-	mrtdt=QPen(QColor("#0000ff"),0.7,Qt::SolidLine);
-	lemasl->setPen(mrtdt);
+	ir=new mgzerz(QRubberBand::Line,this);
 
 	QBrush bprl=QBrush();
 
 	QColor fldlgz=QColor(0,0,150,100);
-	kiallt->setBrush(fldlgz);
 
 	QAction *klsirz=0;
 
-	akdaly=new QAction(ts_001,this);
-	akdaly->setShortcut(ts_002);
-        connect(akdaly,SIGNAL(triggered()),this,SLOT(cel()));
-	addAction(akdaly);
+	cel=new QAction(ts_001,this);
+	cel->setShortcut(ts_002);
+        connect(cel,SIGNAL(triggered()),this,SLOT(dolog()));
+	addAction(cel);
 
-	dolog=new QAction(ts_003,this);
-	dolog->setShortcut(ts_004);
-        connect(dolog,SIGNAL(triggered()),this,SLOT(fladat()));
-	addAction(dolog);
+	fladat=new QAction(ts_003,this);
+	fladat->setShortcut(ts_004);
+        connect(fladat,SIGNAL(triggered()),this,SLOT(zandek()));
+	addAction(fladat);
 
-	zandek=new QAction(ts_005,this);
-	zandek->setShortcut(ts_006);
-        connect(zandek,SIGNAL(triggered()),this,SLOT(targy()));
-	addAction(zandek);
+	targy=new QAction(ts_005,this);
+	targy->setShortcut(ts_006);
+        connect(targy,SIGNAL(triggered()),this,SLOT(alkt()));
+	addAction(targy);
 
 	klsirz=new QAction(ts_007,this);
 	klsirz->setShortcut(ts_008);
-        connect(klsirz,SIGNAL(triggered()),this,SLOT(kitolt()));
+        connect(klsirz,SIGNAL(triggered()),this,SLOT(megir()));
 	addAction(klsirz);
 
-	klsirz=new QAction(ts_009,this); klsirz->setShortcut(ts_010); connect(klsirz,SIGNAL(triggered()),this,SLOT(amkzrs())); addAction(klsirz); klsirz->setData(QVariant(0));
-	klsirz=new QAction(ts_011,this); klsirz->setShortcut(ts_012); connect(klsirz,SIGNAL(triggered()),this,SLOT(amkzrs())); addAction(klsirz); klsirz->setData(QVariant(1));
-	klsirz=new QAction(ts_013,this); klsirz->setShortcut(ts_014); connect(klsirz,SIGNAL(triggered()),this,SLOT(amkzrs())); addAction(klsirz); klsirz->setData(QVariant(2));
-	klsirz=new QAction(ts_015,this); klsirz->setShortcut(ts_016); connect(klsirz,SIGNAL(triggered()),this,SLOT(amkzrs())); addAction(klsirz); klsirz->setData(QVariant(3));
+	klsirz=new QAction(ts_009,this); klsirz->setShortcut(ts_010); connect(klsirz,SIGNAL(triggered()),this,SLOT(lemasl())); addAction(klsirz); klsirz->setData(QVariant(0));
+	klsirz=new QAction(ts_011,this); klsirz->setShortcut(ts_012); connect(klsirz,SIGNAL(triggered()),this,SLOT(lemasl())); addAction(klsirz); klsirz->setData(QVariant(1));
+	klsirz=new QAction(ts_013,this); klsirz->setShortcut(ts_014); connect(klsirz,SIGNAL(triggered()),this,SLOT(lemasl())); addAction(klsirz); klsirz->setData(QVariant(2));
+	klsirz=new QAction(ts_015,this); klsirz->setShortcut(ts_016); connect(klsirz,SIGNAL(triggered()),this,SLOT(lemasl())); addAction(klsirz); klsirz->setData(QVariant(3));
 
-	klsirz=new QAction(ts_017,this); klsirz->setShortcut(ts_018); connect(klsirz,SIGNAL(triggered()),this,SLOT(marka())); addAction(klsirz); klsirz->setData(QVariant(0));
-	klsirz=new QAction(ts_019,this); klsirz->setShortcut(ts_020); connect(klsirz,SIGNAL(triggered()),this,SLOT(marka())); addAction(klsirz); klsirz->setData(QVariant(1));
-	klsirz=new QAction(ts_021,this); klsirz->setShortcut(ts_022); connect(klsirz,SIGNAL(triggered()),this,SLOT(marka())); addAction(klsirz); klsirz->setData(QVariant(2));
-	klsirz=new QAction(ts_023,this); klsirz->setShortcut(ts_024); connect(klsirz,SIGNAL(triggered()),this,SLOT(marka())); addAction(klsirz); klsirz->setData(QVariant(3));
+	klsirz=new QAction(ts_017,this); klsirz->setShortcut(ts_018); connect(klsirz,SIGNAL(triggered()),this,SLOT(kiallt())); addAction(klsirz); klsirz->setData(QVariant(0));
+	klsirz=new QAction(ts_019,this); klsirz->setShortcut(ts_020); connect(klsirz,SIGNAL(triggered()),this,SLOT(kiallt())); addAction(klsirz); klsirz->setData(QVariant(1));
+	klsirz=new QAction(ts_021,this); klsirz->setShortcut(ts_022); connect(klsirz,SIGNAL(triggered()),this,SLOT(kiallt())); addAction(klsirz); klsirz->setData(QVariant(2));
+	klsirz=new QAction(ts_023,this); klsirz->setShortcut(ts_024); connect(klsirz,SIGNAL(triggered()),this,SLOT(kiallt())); addAction(klsirz); klsirz->setData(QVariant(3));
 
-	klsirz=new QAction(ts_025,this); klsirz->setShortcut(ts_026); connect(klsirz,SIGNAL(triggered()),this,SLOT(kesztm())); addAction(klsirz); klsirz->setData(QVariant(1));
+	klsirz=new QAction(ts_025,this); klsirz->setShortcut(ts_026); connect(klsirz,SIGNAL(triggered()),this,SLOT(kitolt())); addAction(klsirz); klsirz->setData(QVariant(1));
 
-	alkt=new QMenu(this);
-	alkt->addAction(dolog);
-	alkt->addAction(akdaly);
-	alkt->addAction(zandek);
-	korrkt=alkt->addMenu(ts_027);
-	jo=alkt->addMenu(ts_028);
+	elodez=new QMenu(this);
+	elodez->addAction(fladat);
+	elodez->addAction(cel);
+	elodez->addAction(targy);
+	korrkt=elodez->addMenu(ts_027);
+	jo=elodez->addMenu(ts_028);
 
 	klsirz=new QAction(ts_029,this); connect(klsirz,SIGNAL(triggered()),this,SLOT(kapni())); addAction(klsirz); klsirz->setData(QVariant(nztsvg));
 	jo->addAction(klsirz);
@@ -136,16 +126,16 @@ felu::felu(QWidget *irnyjl,jelzpn *megkap) : QGraphicsView(irnyjl)
 	jo->addAction(klsirz);
 %>
 
-void felu::kesztm()
+void felu::kitolt()
 <%
 	switch(((QAction*) QObject::sender())->data().toInt())
 	<%
 		case 0:
-			if(hzzqjt.size()>1) elodez();
+			if(hzzqjt.size()>1) hsztzk();
 			kidlgz->mozog();
 			break;
 		case 1:
-			if(hzzqjt.size()>1) elodez();
+			if(hzzqjt.size()>1) hsztzk();
 			kidlgz->rabir();
 			break;
 		default:
@@ -154,92 +144,92 @@ void felu::kesztm()
 	if(hzzqjt.size()==1) ensureVisible(hzzqjt[0]);
 %>
 
-void felu::cel()
+void felu::dolog()
 <%
 	if(hzzqjt.size()==1)
 	<%
-		if(hzzqjt[0]->kapni)
+		if(hzzqjt[0]->kapod)
 		<%
 			QFocusEvent adelk=QFocusEvent(QEvent::FocusOut);
-			hzzqjt[0]->lmzdul(&adelk);
+			hzzqjt[0]->elktzk(&adelk);
 			hzzqjt[0]->update();
 		%>
 		else
 		<%
-			hzzqjt[0]->jvsltz();
+			hzzqjt[0]->lmzdul();
 			hzzqjt[0]->update();
 		%>
 	%>
 %>
 
-void felu::amkzrs()
+void felu::lemasl()
 <%
 	if(hzzqjt.size() < 1) return;
 	switch(((QAction*) QObject::sender())->data().toInt())
 	<%
-		case 0: kivitl(0,-20); break;
-		case 1: kivitl(0,20); break;
-		case 2: kivitl(-20,0); break;
-		case 3: kivitl(20,0); break;
+		case 0: amkzrs(0,-20); break;
+		case 1: amkzrs(0,20); break;
+		case 2: amkzrs(-20,0); break;
+		case 3: amkzrs(20,0); break;
 		default: break;
 	%>
 %>
 
-void felu::marka()
+void felu::kiallt()
 <%
 	if(hzzqjt.size()!=1) return;
-	int bprl=hzzqjt[0]->Id();
+	int irnyjl=hzzqjt[0]->Id();
 	switch(((QAction*) QObject::sender())->data().toInt())
 	<%
-		case 0: kidlgz->mgzerz(bprl,3); break;
-		case 1: kidlgz->mgzerz(bprl,4); break;
-		case 2: kidlgz->mgzerz(bprl,1); break;
-		case 3: kidlgz->mgzerz(bprl,2); break;
+		case 0: kidlgz->mgzerz(irnyjl,3); break;
+		case 1: kidlgz->mgzerz(irnyjl,4); break;
+		case 2: kidlgz->mgzerz(irnyjl,1); break;
+		case 3: kidlgz->mgzerz(irnyjl,2); break;
 		default: break;
 	%>
 	if(hzzqjt.size()==1) ensureVisible(hzzqjt[0]);
 %>
 
-void felu::fladat()
+void felu::zandek()
 <%
-	int bprl=0;
-	if(hzzqjt.size()==1) bprl=hzzqjt[0]->Id();
-	elodez();
+	int irnyjl=0;
+	if(hzzqjt.size()==1) irnyjl=hzzqjt[0]->Id();
+	hsztzk();
 
-	kidlgz->kapod(bprl);
+	kidlgz->kapod(irnyjl);
 	kidlgz->kapni();
-	if(hzzqjt.size()==1) hzzqjt[0]->jvsltz();
+	if(hzzqjt.size()==1) hzzqjt[0]->lmzdul();
 %>
 
-void felu::kitolt()
+void felu::megir()
 <%
 	if(hzzqjt.size()!=1) return;
-	int bprl=kidlgz->prmz(hzzqjt[0]->Id());
-	if(bprl==0) return;
-	elodez();
+	int irnyjl=kidlgz->prmz(hzzqjt[0]->Id());
+	if(irnyjl==0) return;
+	hsztzk();
 
-	kidlgz->kapod(bprl);
+	kidlgz->kapod(irnyjl);
 	kidlgz->kapni();
-	if(hzzqjt.size()==1) hzzqjt[0]->jvsltz();
+	if(hzzqjt.size()==1) hzzqjt[0]->lmzdul();
 %>
 
-void felu::targy()
+void felu::alkt()
 <%
-	QList<int> fldlgz;
+	QList<int> bprl;
 	foreach(QGraphicsItem *prl,hzzqjt)
 	<%
 		if(prl->type()!=gratype(7)) continue;
 		rslt *adelk =(rslt*) prl;
-		fldlgz.push_back(adelk->Id());
+		bprl.push_back(adelk->Id());
 	%>
-	foreach(int adelk,fldlgz)
+	foreach(int adelk,bprl)
 	<%
 		kidlgz->jo(adelk);
 	%>
 	kidlgz->korrkt(0);
 %>
 
-void felu::gyrtmn(int lnmtat,bool fnqll)
+void felu::marka(int lnmtat,bool fnqll)
 <%
 	int j=0;
 	for(int i=0; i<kidlgz->eler.size(); i++)
@@ -261,18 +251,18 @@ void felu::gyrtmn(int lnmtat,bool fnqll)
 	%>
 %>
 
-void felu::kivitl(int mzgat,int sima)
+void felu::amkzrs(int mzgat,int sima)
 <%
-	hsztzk();
+	jlnrdz();
 	foreach(rslt *prl,hzzqjt) <% prl->moveBy(mzgat,sima); %>
-	foreach(rslt *prl,hzzqjt) <% prl->kltzik(); ensureVisible(prl); %>
+	foreach(rslt *prl,hzzqjt) <% prl->jvsltz(); ensureVisible(prl); %>
 %>
 
-void felu::eler(fajta mozog)
+void felu::kesztm(kivitl eler)
 <%
-	elodez();
+	hsztzk();
 
-	switch(mozog)
+	switch(eler)
 	<%
 		case meghat:
 			viewport()->setCursor(Qt::ArrowCursor);
@@ -289,147 +279,147 @@ void felu::eler(fajta mozog)
 		default:
 			break;
 	%>
-	ir=mozog;
+	fortum=eler;
 
-	nybnvn=0;
-	kiallt->hide();
-	lemasl->hide();
+	akdaly=0;
+	kapod->hide();
+	ir->hide();
 %>
 
-void felu::keyReleaseEvent(QKeyEvent *jlnrdz)
+void felu::keyReleaseEvent(QKeyEvent *kelt)
 <%
 #if 0
 	if(hzzqjt.size()==1)
         <%
-                hzzqjt[0]->keyReleaseEvent(jlnrdz);
+                hzzqjt[0]->keyReleaseEvent(kelt);
                 return;
         %>
-	QApplication::sendEvent(scene(),jlnrdz);
+	QApplication::sendEvent(scene(),kelt);
 #endif
-	jlnrdz->accept();
+	kelt->accept();
 %>
 
-void felu::keyPressEvent(QKeyEvent *jlnrdz)
+void felu::keyPressEvent(QKeyEvent *kelt)
 <%
 	if(hzzqjt.size()==1)
 	<%
 		rslt * prl=hzzqjt[0];
-		if(prl->kapni and jlnrdz->type()==QEvent::KeyPress)
+		if(prl->kapod and kelt->type()==QEvent::KeyPress)
 		<%
-			prl->keyPressEvent(jlnrdz);
+			prl->keyPressEvent(kelt);
 		%>
 	%>
-	jlnrdz->accept();
+	kelt->accept();
 %>
 
-void felu::zoom_in()
+void felu::rabir()
 <%
-	double mrtdt=1.05;
-	qreal adelk=matrix().scale(mrtdt,mrtdt).mapRect(QRectF(0,0,1,1)).width();
+	double irnyjl=1.05;
+	qreal adelk=matrix().scale(irnyjl,irnyjl).mapRect(QRectF(0,0,1,1)).width();
 	if(adelk < 0.01 or adelk > 1000) return;
-	scale(mrtdt,mrtdt);
+	scale(irnyjl,irnyjl);
 %>
 
-void felu::zoom_out()
+void felu::mozog()
 <%
-	double mrtdt=0.95;
-	qreal adelk=matrix().scale(mrtdt,mrtdt).mapRect(QRectF(0,0,1,1)).width();
+	double irnyjl=0.95;
+	qreal adelk=matrix().scale(irnyjl,irnyjl).mapRect(QRectF(0,0,1,1)).width();
 	if(adelk < 0.01 or adelk > 1000) return;
-	scale(mrtdt,mrtdt);
+	scale(irnyjl,irnyjl);
 %>
 
-void felu::wheelEvent(QWheelEvent *jlnrdz)
+void felu::wheelEvent(QWheelEvent *kelt)
 <%
-	QPointF klsirz=mapToScene(jlnrdz->pos());
-	qreal mrtdt=pow(2.0,-jlnrdz->delta() / 440.0);
-	qreal adelk=matrix().scale(mrtdt,mrtdt).mapRect(QRectF(0,0,1,1)).width();
+	QPointF klsirz=mapToScene(kelt->pos());
+	qreal irnyjl=pow(2.0,kelt->delta() / 440.0);
+	qreal adelk=matrix().scale(irnyjl,irnyjl).mapRect(QRectF(0,0,1,1)).width();
 	if(adelk < 0.01 or adelk > 1000) return;
-	scale(mrtdt,mrtdt);
-	centerOn(klsirz + mapToScene(viewport()->rect().center()) - mapToScene(jlnrdz->pos()));
+	scale(irnyjl,irnyjl);
+	centerOn(klsirz + mapToScene(viewport()->rect().center()) - mapToScene(kelt->pos()));
 %>
 
-bool felu::event(QEvent *jlnrdz)
+bool felu::event(QEvent *kelt)
 <%
-	if(jlnrdz->type()==QEvent::ToolTip)
+	if(kelt->type()==QEvent::ToolTip)
 	<%
-		QHelpEvent *adelk=static_cast<QHelpEvent*>(jlnrdz);
+		QHelpEvent *adelk=static_cast<QHelpEvent*>(kelt);
 		QGraphicsItem *prl=scene()->itemAt(mapToScene(adelk->pos()));
 		if(prl and prl->type()==gratype(7))
 		<%
 			prmza *klsirz=*kidlgz +((rslt*) prl)->Id();
-			if(klsirz and klsirz->kapni > 1)
+			if(klsirz and klsirz->kapod > 1)
 			<%
-				QToolTip::showText(adelk->globalPos(),klsirz->rabir);
+				QToolTip::showText(adelk->globalPos(),klsirz->mozog);
 			%>
 		%>
 	%>
-	else if(jlnrdz->type()==QEvent::InputMethod)
+	else if(kelt->type()==QEvent::InputMethod)
 	<%
 		if(hzzqjt.size()==1)
 		<%
 			rslt * prl=hzzqjt[0];
-			if(prl->kapni)
+			if(prl->kapod)
 			<%
-				prl->inputMethodEvent((QInputMethodEvent*) jlnrdz);
+				prl->inputMethodEvent((QInputMethodEvent*) kelt);
 			%>
 		%>
 	%>
-	else if(jlnrdz->type()==QEvent::KeyPress
-		or jlnrdz->type()==QEvent::ShortcutOverride
-		or jlnrdz->type()==QEvent::Shortcut)
+	else if(kelt->type()==QEvent::KeyPress
+		or kelt->type()==QEvent::ShortcutOverride
+		or kelt->type()==QEvent::Shortcut)
 	<%
-		if(hzzqjt.size()==1 and hzzqjt[0]->kapni)
+		if(hzzqjt.size()==1 and hzzqjt[0]->kapod)
 		<%
-			QKeyEvent *klsirz =(QKeyEvent*) jlnrdz;
-			if(akdaly->shortcut().matches(klsirz->key()))
+			QKeyEvent *klsirz =(QKeyEvent*) kelt;
+			if(cel->shortcut().matches(klsirz->key()))
 			<%
-				return QGraphicsView::event(jlnrdz);
+				return QGraphicsView::event(kelt);
 			%>
 
 			keyPressEvent(klsirz);
 			return 1;
 		%>
 	%>
-	return QGraphicsView::event(jlnrdz);
+	return QGraphicsView::event(kelt);
 %>
 
 void felu::focusOutEvent(QFocusEvent *mgmnkl)
 <%
 	foreach(rslt *prl,hzzqjt)
         <%
-		prl->lmzdul(mgmnkl);
+		prl->elktzk(mgmnkl);
         %>
 	foreach(QAction* klsirz,actions())
 	<%
 		klsirz->setEnabled(0);
 	%>
-	if(alkt->isVisible()) lep();
+	if(elodez->isVisible()) lep();
 %>
 
 /*!
  * eow this actually works
  */
-void felu::kelt(const zagv& tqrost)
+void felu::kivalt(const zagv& tqrost)
 <%
-	int kivalt=tqrost[3].toInt();
-	switch(kivalt)
+	int fldlgz=tqrost[3].toInt();
+	switch(fldlgz)
 	<%
 		case ossz:
 			<%
-				int bprl=tqrost[2].toInt();
+				int irnyjl=tqrost[2].toInt();
 
-				rslt*adelk=new rslt(this,bprl);
+				rslt*adelk=new rslt(this,irnyjl);
 
 				adelk->setSelected(1);
 
 				QRectF vnl=adelk->boundingRect();
 				adelk->setPos(vmrgem - QPointF(vnl.width()/2,vnl.height()/2));
 
-				prmza *eljar=*kidlgz + bprl;
-				eljar->kapod=adelk->pos().x();
-				eljar->mgzerz=adelk->pos().y();
+				prmza *eljar=*kidlgz + irnyjl;
+				eljar->mgzerz=adelk->pos().x();
+				eljar->rabir=adelk->pos().y();
 
-				kket[bprl]=adelk;
+				kket[irnyjl]=adelk;
 			%>
 			break;
 		case krszt:
@@ -444,27 +434,27 @@ void felu::kelt(const zagv& tqrost)
 			<%
 				if(tqrost[jelzpo].toInt()==nztutb)
 				<%
-					detto();
+					gyrtmn();
 					return;
 				%>
-				int bprl=tqrost[2].toInt();
-				if(bprl==0)
+				int irnyjl=tqrost[2].toInt();
+				if(irnyjl==0)
 				<%
-					elodez(0);
+					hsztzk(0);
 				%>
 				else if(hzzqjt.size()==1)
 				<%
-					if(hzzqjt[0]->Id()!=bprl)
+					if(hzzqjt[0]->Id()!=irnyjl)
 					<%
 						elktzk(hzzqjt[0],0);
-						lmzdul(kket.value(bprl),0);
+						lmzdul(kket.value(irnyjl),0);
 					%>
 				%>
 				else
 				<%
-					lmzdul(kket.value(bprl),0);
+					lmzdul(kket.value(irnyjl),0);
 				%>
-				detto();
+				gyrtmn();
 			%>
 			break;
 		case lnc:
@@ -472,7 +462,7 @@ void felu::kelt(const zagv& tqrost)
 				rslt *prmz=kket.value(tqrost[2].toInt());
 				rslt *bprl=kket.value(tqrost[0].toInt());
 				izlt * felvnl=new izlt(this,bprl,prmz);
-				felvnl->vmrgem();
+				felvnl->jlnrdz();
 				prmz->update();
 			%>
 			break;
@@ -487,9 +477,9 @@ void felu::kelt(const zagv& tqrost)
 					<%
 						izlt *felvnl =(izlt*) prl;
 						if(
-							(felvnl->akdaly==prmz and felvnl->nybnvn==bprl)
+							(felvnl->cel==prmz and felvnl->akdaly==bprl)
 							or
-							(felvnl->akdaly==bprl and felvnl->nybnvn==prmz)
+							(felvnl->cel==bprl and felvnl->akdaly==prmz)
 						)
 						<%
 							felvnl->hide();
@@ -505,11 +495,11 @@ void felu::kelt(const zagv& tqrost)
 			break;
 		case oszy:
 			<%
-				int bprl=tqrost[2].toInt();
-				rslt *prmz=kket.value(bprl);
+				int irnyjl=tqrost[2].toInt();
+				rslt *prmz=kket.value(irnyjl);
 
 				hzzqjt.removeAll(prmz);
-				kket.remove(bprl);
+				kket.remove(irnyjl);
 
 				scene()->removeItem(prmz);
 				delete prmz;
@@ -517,7 +507,7 @@ void felu::kelt(const zagv& tqrost)
 			break;
 		case mod:
 			<%
-				gyrtmn(hzzqjt[0]->Id(),ir==tiszta);
+				marka(hzzqjt[0]->Id(),fortum==tiszta);
 			%>
 			break;
 		case kivdlk:
@@ -526,95 +516,95 @@ void felu::kelt(const zagv& tqrost)
 				foreach(rslt *prl,jlzpnt)
 				<%
 					prmza *eljar=*kidlgz + prl->Id();
-					eljar->kapod=prl->pos().x();
-					eljar->mgzerz=prl->pos().y();
-					eljar->mrtdt=prl->boundingRect().width();
-					eljar->adelk=prl->boundingRect().height();
+					eljar->mgzerz=prl->pos().x();
+					eljar->rabir=prl->pos().y();
+					eljar->bprl=prl->boundingRect().width();
+					eljar->mrtdt=prl->boundingRect().height();
 				%>
 			%>
 			break;
 		case krszelgyk:
 			<%
-				ablkl *klsirz =(ablkl*) nagy;
-				klsirz->munka->clear();
+				ablkl *klsirz =(ablkl*) leir;
+				klsirz->fladat->clear();
 
-				while(klsirz->korrkt->actions().size() > kidlgz->kitzjl.size())
+				while(klsirz->dolog->actions().size() > kidlgz->kitzjl.size())
 				<%
-					QAction* adelk=klsirz->korrkt->actions().takeFirst();
+					QAction* adelk=klsirz->dolog->actions().takeFirst();
 					delete adelk;
 				%>
 
-				while(klsirz->korrkt->actions().size() < kidlgz->kitzjl.size())
+				while(klsirz->dolog->actions().size() < kidlgz->kitzjl.size())
 				<%
-					new QAction(QIcon(),ts_033,klsirz->korrkt);
+					new QAction(QIcon(),ts_033,klsirz->dolog);
 				%>
 
 				for(int i=0; i<kidlgz->kitzjl.size(); ++i)
 				<%
-					elgy* adelk=kidlgz->kitzjl[i];
-					QAction *jlzpnt=klsirz->korrkt->actions()[i];
+					elgy* irnyjl=kidlgz->kitzjl[i];
+					QAction *jlzpnt=klsirz->dolog->actions()[i];
 
-					jlzpnt->setText(adelk->eler);
-					jlzpnt->setIcon(adelk->kitzjl());
+					jlzpnt->setText(irnyjl->kidlgz);
+					jlzpnt->setIcon(irnyjl->prmz());
 				%>
 
-                                foreach(QAction* bprl,klsirz->korrkt->actions())
+                                foreach(QAction* irnyjl,klsirz->dolog->actions())
                                 <%
-                                        klsirz->munka->addAction(bprl);
-					bprl->setCheckable(1);
+                                        klsirz->fladat->addAction(irnyjl);
+					irnyjl->setCheckable(1);
                                 %>
 			%>
 			break;
 		case krsztszn:
 			<%
-				ablkl *klsirz =(ablkl*) nagy;
-				klsirz->ceco->clear();
+				ablkl *klsirz =(ablkl*) leir;
+				klsirz->cel->clear();
 
-				while(klsirz->csals->actions().size() > kidlgz->munka.size()+1)
+				while(klsirz->akdaly->actions().size() > kidlgz->munka.size()+1)
 				<%
-					QAction* adelk=klsirz->csals->actions().takeFirst();
-					klsirz->ceco->removeAction(adelk);
+					QAction* adelk=klsirz->akdaly->actions().takeFirst();
+					klsirz->cel->removeAction(adelk);
 					korrkt->removeAction(adelk);
 					delete adelk;
 				%>
 
-				while(klsirz->csals->actions().size() < kidlgz->munka.size()+1)
+				while(klsirz->akdaly->actions().size() < kidlgz->munka.size()+1)
 				<%
-					new QAction(QIcon(),ts_034,klsirz->csals);
+					new QAction(QIcon(),ts_034,klsirz->akdaly);
 				%>
 
-				klsirz->csals->removeAction(klsirz->jo);
-				klsirz->csals->addAction(klsirz->jo);
-				korrkt->removeAction(klsirz->jo);
-				korrkt->addAction(klsirz->jo);
+				klsirz->akdaly->removeAction(klsirz->hzzqjt);
+				klsirz->akdaly->addAction(klsirz->hzzqjt);
+				korrkt->removeAction(klsirz->hzzqjt);
+				korrkt->addAction(klsirz->hzzqjt);
 
 				for(int i=0; i<kidlgz->munka.size(); ++i)
 				<%
-					szn adelk=kidlgz->munka[i];
-					QAction *jlzpnt=klsirz->csals->actions()[i];
+					szn irnyjl=kidlgz->munka[i];
+					QAction *jlzpnt=klsirz->akdaly->actions()[i];
 
-					QPixmap fldlgz(22,22);
-					QPainter mrtdt(&fldlgz);
+					QPixmap adelk(22,22);
+					QPainter mrtdt(&adelk);
 
-					jlzpnt->setText(adelk.eler);
+					jlzpnt->setText(irnyjl.kidlgz);
 
-					fldlgz.fill(adelk.kitzjl);
+					adelk.fill(irnyjl.kitzjl);
 					mrtdt.drawRect(0,0,21,21);
-					jlzpnt->setIcon(QIcon(fldlgz));
+					jlzpnt->setIcon(QIcon(adelk));
 				%>
 
-				for(int i=1; i<klsirz->csals->actions().size(); ++i)
+				for(int i=1; i<klsirz->akdaly->actions().size(); ++i)
 				<%
-					QAction *bprl=klsirz->csals->actions()[i];
-					klsirz->ceco->addAction(bprl);
-					korrkt->addAction(bprl);
+					QAction *irnyjl=klsirz->akdaly->actions()[i];
+					klsirz->cel->addAction(irnyjl);
+					korrkt->addAction(irnyjl);
 				%>
 			%>
 			break;
 		case nytt:
 			<%
-				hsztzk();
-				rabir();
+				jlnrdz();
+				fajta();
 			%>
 			break;
 		default:
@@ -622,17 +612,17 @@ void felu::kelt(const zagv& tqrost)
 	%>
 %>
 
-void felu::mgzerz(QAction* mrtdt)
+void felu::detto(QAction* mrtdt)
 <%
 	static QColor fldlgz;
 
 	int adelk=-1;
-	ablkl *klsirz =(ablkl*) nagy;
-	for(int i=1; i<klsirz->csals->actions().size(); ++i)
+	ablkl *klsirz =(ablkl*) leir;
+	for(int i=1; i<klsirz->akdaly->actions().size(); ++i)
 	<%
-		if(klsirz->csals->actions()[i]==mrtdt and(adelk=i))
+		if(klsirz->akdaly->actions()[i]==mrtdt and(adelk=i))
 		<%
-			if(i==klsirz->csals->actions().size()-1)
+			if(i==klsirz->akdaly->actions().size()-1)
 			<%
 				fldlgz=QColorDialog::getColor(fldlgz,this);
 				if(!fldlgz.isValid()) return;
@@ -644,38 +634,38 @@ void felu::mgzerz(QAction* mrtdt)
 	for(int i=0; i<hzzqjt.size(); ++i)
 	<%
 		rslt *prl=hzzqjt[i];
-		int alafng=prl->Id();
-		prmza *eljar=*kidlgz + alafng;
+		int irnyjl=prl->Id();
+		prmza *eljar=*kidlgz + irnyjl;
 		eljar->letsit.kitzjl=fldlgz;
-		eljar->letsit.kidlgz=fldlgz.dark();
-		eljar->kapod=prl->pos().x();
-		eljar->mgzerz=prl->pos().y();
-		eljar->jo=adelk;
-		kidlgz->lep(alafng);
+		eljar->letsit.jlzpnt=fldlgz.dark();
+		eljar->mgzerz=prl->pos().x();
+		eljar->rabir=prl->pos().y();
+		eljar->kapni=adelk;
+		kidlgz->lep(irnyjl);
 	%>
 %>
 
-void felu::kapod(QAction* kivalt)
+void felu::alafng(QAction* letsit)
 <%
-	int alafng=0;
-	ablkl *klsirz =(ablkl*) nagy;
-	for(int i=0; i<klsirz->korrkt->actions().size(); ++i)
+	int rgsztg=0;
+	ablkl *klsirz =(ablkl*) leir;
+	for(int i=0; i<klsirz->dolog->actions().size(); ++i)
 	<%
-		QAction *bprl=klsirz->korrkt->actions()[i];
-		if(bprl==kivalt) alafng=i;
+		QAction *irnyjl=klsirz->dolog->actions()[i];
+		if(irnyjl==letsit) rgsztg=i;
 	%>
-	QString jlzpnt=kidlgz->kitzjl[alafng]->kidlgz;
+	QString jlzpnt=kidlgz->kitzjl[rgsztg]->kket;
 	rslt *prl=hzzqjt[0];
 	prmza *eljar=*kidlgz + hzzqjt[0]->Id();
 
-	if(kivalt->isChecked()) eljar->prmz.push_back(jlzpnt);
+	if(letsit->isChecked()) eljar->prmz.push_back(jlzpnt);
 	else eljar->prmz.removeAll(jlzpnt);
-	prl->lep();
+	prl->kltzik();
 %>
 
-void felu::detto()
+void felu::gyrtmn()
 <%
-	ablkl *klsirz =(ablkl*) nagy;
+	ablkl *klsirz =(ablkl*) leir;
 	bool adelk =(hzzqjt.size()==1);
 	prmza *eljar=0;
 	if(adelk)
@@ -683,40 +673,40 @@ void felu::detto()
 		eljar=*kidlgz + hzzqjt[0]->Id();
 	%>
 
-	for(int i=0; i<klsirz->korrkt->actions().size(); ++i)
+	for(int i=0; i<klsirz->dolog->actions().size(); ++i)
 	<%
-		QAction *bprl=klsirz->korrkt->actions()[i];
+		QAction *irnyjl=klsirz->dolog->actions()[i];
 
-		if(!adelk) bprl->setChecked(0);
+		if(!adelk) irnyjl->setChecked(0);
 		else
 		<%
-			QString jlzpnt=kidlgz->kitzjl[i]->kidlgz;
-			bprl->setChecked(eljar->prmz.contains(jlzpnt));
+			QString jlzpnt=kidlgz->kitzjl[i]->kket;
+			irnyjl->setChecked(eljar->prmz.contains(jlzpnt));
 		%>
-		bprl->setEnabled(adelk);
+		irnyjl->setEnabled(adelk);
 	%>
 	adelk =(hzzqjt.size()>=1);
-	foreach(QAction* bprl,klsirz->csals->actions())
+	foreach(QAction* irnyjl,klsirz->akdaly->actions())
 	<%
-		bprl->setEnabled(adelk);
+		irnyjl->setEnabled(adelk);
 	%>
 %>
 
-void felu::elodez(bool lecke)
+void felu::hsztzk(bool lecke)
 <%
 	if(hzzqjt.size()==1)
 	<%
 		QFocusEvent adelk=QFocusEvent(QEvent::FocusOut);
-		hzzqjt[0]->lmzdul(&adelk);
+		hzzqjt[0]->elktzk(&adelk);
 	%>
 
 	foreach(rslt *prl,hzzqjt)
 	<%
-		prl->alkt(0);
+		prl->targy(0);
 		prl->setZValue(99);
-		if(ir==tiszta or megir==tiszta)
+		if(fortum==tiszta or nagy==tiszta)
 		<%
-			gyrtmn(prl->Id(),0);
+			marka(prl->Id(),0);
 			emit jvsltz("",-1);
 		%>
 		prl->update();
@@ -732,16 +722,16 @@ void felu::lmzdul(rslt* eljar,bool lecke)
 	if(hzzqjt.size()==1)
         <%
 		QFocusEvent adelk=QFocusEvent(QEvent::FocusOut);
-		hzzqjt[0]->lmzdul(&adelk);
+		hzzqjt[0]->elktzk(&adelk);
         %>
 
 	fhlhjt=0;
 	hzzqjt.push_back(eljar);
-	eljar->alkt(1);
+	eljar->targy(1);
 	eljar->setZValue(100);
-	if(ir==tiszta)
+	if(fortum==tiszta)
 	<%
-		gyrtmn(eljar->Id(),1);
+		marka(eljar->Id(),1);
 		emit jvsltz(ts_035.arg(QString::number(fhlhjt+1)),-1);
 	%>
 	eljar->update();
@@ -751,9 +741,9 @@ void felu::lmzdul(rslt* eljar,bool lecke)
 
 void felu::elktzk(rslt* eljar,bool lecke)
 <%
-	eljar->alkt(0);
+	eljar->targy(0);
 	eljar->setZValue(99);
-	if(ir==tiszta) gyrtmn(eljar->Id(),0);
+	if(fortum==tiszta) marka(eljar->Id(),0);
 	eljar->update();
 	hzzqjt.removeAll(eljar);
 
@@ -782,9 +772,9 @@ void felu::kltzik()
 
 void felu::lep()
 <%
-	dolog->setEnabled(hzzqjt.size()<=1);
-	zandek->setEnabled(hzzqjt.size()>0);
-	akdaly->setEnabled(hzzqjt.size()==1);
+	fladat->setEnabled(hzzqjt.size()<=1);
+	targy->setEnabled(hzzqjt.size()>0);
+	cel->setEnabled(hzzqjt.size()==1);
 	korrkt->setEnabled(hzzqjt.size()>=1);
 	jo->setEnabled(hzzqjt.size()==1);
 	foreach(QAction* klsirz,jo->actions())
@@ -803,36 +793,36 @@ void felu::mousePressEvent(QMouseEvent *mgmnkl)
 		<%
 			if(!hzzqjt.contains((rslt*) prl))
 			<%
-				elodez();
+				hsztzk();
 				lmzdul((rslt*) prl);
 			%>
 		%>
 		else
 		<%
-			elodez();
+			hsztzk();
 		%>
-		alkt->popup(mgmnkl->globalPos());
+		elodez->popup(mgmnkl->globalPos());
 		return;
 	%>
 
 	if(mgmnkl->button()==Qt::MidButton)
 	<%
-		megir=ir;
-		ir=ugyex;
+		nagy=fortum;
+		fortum=ugyex;
 	%>
 
 	rslt *vnl=0;
-	switch(ir)
+	switch(fortum)
 	<%
 		case meghat:
 			<%
 				ellqts=mgmnkl->pos();
 				kitzjl=mapToScene(ellqts);
 
-				nybnvn =(mgmnkl->button()==Qt::LeftButton);
+				akdaly =(mgmnkl->button()==Qt::LeftButton);
 
 				QGraphicsItem *prl=scene()->itemAt(mapToScene(mgmnkl->pos()));
-				if(nybnvn)
+				if(akdaly)
 				<%
 					if(prl and prl->type()==gratype(7))
 					<%
@@ -861,14 +851,14 @@ void felu::mousePressEvent(QMouseEvent *mgmnkl)
 					if(QApplication::keyboardModifiers() & Qt::ControlModifier)
 						kidlgz->csals(hzzqjt[0]->Id(),vnl->Id());
 				%>
-				elodez();
+				hsztzk();
 				lmzdul(vnl);
 			%>
 						%>
 					%>
 					else
 					<%
-						elodez();
+						hsztzk();
 					%>
 				%>
 
@@ -877,9 +867,9 @@ void felu::mousePressEvent(QMouseEvent *mgmnkl)
 		case tljsn:
 			<%
 				ellqts=mgmnkl->pos();
-				nybnvn =(mgmnkl->button()==Qt::LeftButton);
+				akdaly =(mgmnkl->button()==Qt::LeftButton);
 
-				elodez();
+				hsztzk();
 				QGraphicsItem *prl=scene()->itemAt(mapToScene(mgmnkl->pos()));
 				if(prl and prl->type()==gratype(7))
 				<%
@@ -894,18 +884,18 @@ void felu::mousePressEvent(QMouseEvent *mgmnkl)
 				if(prl and prl->type()==gratype(7))
 				<%
 					vnl =(rslt*) prl;
-					elodez();
+					hsztzk();
 					lmzdul(vnl);
 				%>
 				else if(prl and prl->type()==gratype(19))
 				<%
 
 					szrt * adelk =(szrt*) prl;
-					int bprl=adelk->akdaly->Id();
-					vnl=adelk->akdaly;
+					int irnyjl=adelk->cel->Id();
+					vnl=adelk->cel;
 
-					kidlgz->ceco(hzzqjt[0]->Id(),bprl,fhlhjt);
-					gyrtmn(hzzqjt[0]->Id(),1);
+					kidlgz->ceco(hzzqjt[0]->Id(),irnyjl,fhlhjt);
+					marka(hzzqjt[0]->Id(),1);
 
 					fhlhjt++;
 					if(fhlhjt >= kidlgz->ellqts(hzzqjt[0]->Id()))
@@ -915,18 +905,18 @@ void felu::mousePressEvent(QMouseEvent *mgmnkl)
 				%>
 				else
 				<%
-					elodez();
+					hsztzk();
 				%>
 			%>
 			break;
 		case ugyex:
 			viewport()->setCursor(Qt::ClosedHandCursor);
 			ellqts=mgmnkl->pos();
-			nybnvn =(mgmnkl->button()==Qt::LeftButton or mgmnkl->button()==Qt::MidButton);
+			akdaly =(mgmnkl->button()==Qt::LeftButton or mgmnkl->button()==Qt::MidButton);
 
-			if(nybnvn)
+			if(akdaly)
 			<%
-				elodez();
+				hsztzk();
                                 QGraphicsItem *prl=scene()->itemAt(mapToScene(mgmnkl->pos()));
                                 if(prl and prl->type()==gratype(7))
                                 <%
@@ -943,62 +933,59 @@ void felu::mousePressEvent(QMouseEvent *mgmnkl)
 
 void felu::mouseMoveEvent(QMouseEvent *mgmnkl)
 <%
-	hsztzk();
-	switch(ir)
+	jlnrdz();
+	switch(fortum)
 	<%
 		case meghat:
-			if(nybnvn and hzzqjt.size()==0)
+			if(akdaly and hzzqjt.size()==0)
 			<%
 				bool c1 =((ellqts - mgmnkl->pos()).manhattanLength() >= QApplication::startDragDistance());
-				if(kiallt->isVisible() or c1)
+				if(kapod->isVisible() or c1)
 				<%
 					QRect adelk=QRect(ellqts,mgmnkl->pos()).normalized();
-
-					QRectF vnl=kiallt->rect();
-					vnl.setTopLeft(mapToScene(adelk.topLeft()));
-					vnl.setBottomRight(mapToScene(adelk.bottomRight()));
-					kiallt->setRect(vnl);
+					kapod->setGeometry(adelk);
 				%>
 
-				if(c1) kiallt->show();
+				if(c1) kapod->show();
 			%>
-			else if(nybnvn)
+			else if(akdaly)
 			<%
 
 				QRectF vnl;
 				vnl.setTopLeft(kitzjl);
 				kitzjl=mapToScene(mgmnkl->pos());
 				vnl.setBottomRight(kitzjl);
-				kidlgz->set_dirty();
+				kidlgz->brndez();
 				foreach(rslt *prl,hzzqjt)
 				<%
 					prl->moveBy(vnl.width(),vnl.height());
 				%>
 				foreach(rslt *prl,hzzqjt)
 				<%
-					prl->kltzik();
+					prl->jvsltz();
 				%>
 			%>
 			break;
 		case tljsn:
-			if(nybnvn)
+			if(akdaly)
 			<%
 				bool c1 =((ellqts - mgmnkl->pos()).manhattanLength() >= QApplication::startDragDistance());
-				if(lemasl->isVisible() or c1)
+				if(ir->isVisible() or c1)
 				<%
-					lemasl->setLine(QLineF(mapToScene(ellqts),mapToScene(mgmnkl->pos())));
+					QRect adelk=QRect(ellqts,mgmnkl->pos());
+					ir->setGeometry(adelk);
 				%>
 
 				if(c1)
 				<%
-					lemasl->show();
+					ir->show();
 				%>
 			%>
 			break;
 		case tiszta:
 			break;
 		case ugyex:
-			if(nybnvn)
+			if(akdaly)
 			<%
 				QScrollBar *hBar=horizontalScrollBar();
 				QScrollBar *vBar=verticalScrollBar();
@@ -1023,22 +1010,24 @@ void felu::mouseReleaseEvent(QMouseEvent *mgmnkl)
 <%
 	if(mgmnkl->button()==Qt::RightButton) return;
 
-	if(megir!=mgmozt)
+	if(nagy!=mgmozt)
 	<%
-		ir=megir;
-		megir=mgmozt;
-		viewport()->setCursor(ir==tljsn?Qt::CrossCursor:Qt::ArrowCursor);
+		fortum=nagy;
+		nagy=mgmozt;
+		viewport()->setCursor(fortum==tljsn?Qt::CrossCursor:Qt::ArrowCursor);
 	%>
 
-	switch(ir)
+	switch(fortum)
 	<%
 		case meghat:
 			<%
-				nybnvn=0;
-				if(kiallt->isVisible())
+				akdaly=0;
+				if(kapod->isVisible())
 				<%
-					kiallt->hide();
-					QList<QGraphicsItem *> adelk=scene()->items(kiallt->rect());
+					kapod->hide();
+					QRect vnl=kapod->geometry();
+					QList<QGraphicsItem *> adelk=scene()->items(QRectF(mapToScene(vnl.topLeft()),mapToScene(vnl.bottomRight())));
+
 					foreach(QGraphicsItem *prl,adelk)
 					<%
 						if(prl->type()==gratype(7))
@@ -1051,14 +1040,12 @@ void felu::mouseReleaseEvent(QMouseEvent *mgmnkl)
 			break;
 		case tljsn:
 			<%
-				nybnvn=0;
-
-				QLineF klsirz=lemasl->line();
+				akdaly=0;
 
 				rslt *prmz=0;
 				rslt *bprl=0;
 
-				foreach(QGraphicsItem *fldlgz,scene()->items(klsirz.p1()))
+				foreach(QGraphicsItem *fldlgz,scene()->items(mapToScene(ellqts)))
 				<%
 					if(fldlgz->type()==gratype(7))
 					<%
@@ -1067,7 +1054,7 @@ void felu::mouseReleaseEvent(QMouseEvent *mgmnkl)
 					%>
 				%>
 
-				foreach(QGraphicsItem *fldlgz,scene()->items(klsirz.p2()))
+				foreach(QGraphicsItem *fldlgz,scene()->items(mapToScene(mgmnkl->pos())))
 				<%
 					if(fldlgz->type()==gratype(7))
 					<%
@@ -1079,16 +1066,16 @@ void felu::mouseReleaseEvent(QMouseEvent *mgmnkl)
 				if(prmz and bprl and prmz!=bprl)
 				<%
 					kidlgz->csals(prmz->Id(),bprl->Id());
-					elodez();
+					hsztzk();
 				%>
-				lemasl->hide();
+				ir->hide();
 			%>
 			break;
 		case tiszta:
 			break;
 		case ugyex:
 			viewport()->setCursor(Qt::OpenHandCursor);
-			nybnvn=0;
+			akdaly=0;
 			break;
 		default:
 			break;
@@ -1100,37 +1087,37 @@ void felu::mouseDoubleClickEvent(QMouseEvent* mgmnkl)
 	if(mgmnkl->button()!=Qt::LeftButton) return;
 	vmrgem=mapToScene(mgmnkl->pos());
 	QGraphicsItem *prl=itemAt(mgmnkl->pos());
-	int jlzpnt=0;
-	if(ir==meghat or ir==tljsn)
+	int irnyjl=0;
+	if(fortum==meghat or fortum==tljsn)
 	if(prl)
 	<%
 		if(prl->type()==gratype(7))
 		<%
-			elodez();
+			hsztzk();
 
 			rslt *adelk =(rslt*) prl;
 			adelk->setSelected(0);
-			jlzpnt=kidlgz->kapod(adelk->Id(),0,1);
-			if(hzzqjt.size()==1) hzzqjt[0]->jvsltz();
-			hsztzk();
+			irnyjl=kidlgz->kapod(adelk->Id(),0,1);
+			if(hzzqjt.size()==1) hzzqjt[0]->lmzdul();
+			jlnrdz();
 		%>
 		else if(prl->type()==gratype(17))
 		<%
 			izlt *felvnl =(izlt*) prl;
-			kidlgz->fhlhjt(felvnl->nybnvn->Id(),felvnl->akdaly->Id());
+			kidlgz->fhlhjt(felvnl->akdaly->Id(),felvnl->cel->Id());
 		%>
 	%>
 	else if(mgmnkl->modifiers()!=Qt::ControlModifier)
 	<%
-		jlzpnt=kidlgz->kapod();
-		if(hzzqjt.size()==1) hzzqjt[0]->jvsltz();
+		irnyjl=kidlgz->kapod();
+		if(hzzqjt.size()==1) hzzqjt[0]->lmzdul();
 	%>
 %>
 
 qreal adelk(qreal a,qreal b) <% if(a<b) return a; return b; %>
-qreal felvnl(qreal a,qreal b) <% if(a<b) return b; return a; %>
+qreal irnyjl(qreal a,qreal b) <% if(a<b) return b; return a; %>
 
-void felu::hsztzk()
+void felu::jlnrdz()
 <%
 	QRect vnl=viewport()->rect();
 	if(kket.size() < 1)
@@ -1163,7 +1150,7 @@ void felu::hsztzk()
 	scene()->setSceneRect(bprl);
 %>
 
-void felu::rabir()
+void felu::fajta()
 <%
 #if 0
 	QRectF klsirz;
@@ -1186,5 +1173,30 @@ void felu::kapni()
 	kidlgz->tglalp(hzzqjt[0]->Id(),((QAction*) QObject::sender())->data().toInt());
 %>
 
+mgzerz::mgzerz(QRubberBand::Shape i,QWidget* j) : QRubberBand(i,j)
+<%
+%>
+
+void mgzerz::paintEvent(QPaintEvent *)
+<%
+	QPainter painter(this);
+	painter.setRenderHint(QPainter::Antialiasing);
+    painter.setBrush(QColor(Qt::red));
+	if(kitzjl > 0)
+	<%
+		painter.drawLine(QPoint(0,0),QPoint(size().width(),size().height()));
+	%>
+	else
+	<%
+		painter.drawLine(QPoint(size().width(),0),QPoint(0,size().height()));
+	%>
+%>
+
+void mgzerz::setGeometry(const QRect& tqrost)
+<%
+	kitzjl=tqrost.width() * tqrost.height();
+	QRubberBand::setGeometry(tqrost.normalized());
+%>
+
  %: include  	"Flult.moc" 
 
