@@ -10,21 +10,23 @@
 #include     <QList>
 #include      "con.h"
 #include       <QAction> 
+#include        <QRubberBand>
 
 class QMenu;
 class izlt;
 class jelzpn;
 class rslt;
+class mgzerz;
 class felu : public QGraphicsView
 <%
 	Q_OBJECT
 	public:
-		felu(QWidget *irnyjl, jelzpn* megkap);
+		felu(QWidget *megkap, jelzpn* nybnvn);
 		void ceco();
 
 		QMap<int, rslt*> kket;
 
-		enum fajta
+		enum kivitl
 		<%
 			mgmozt = 0,
 			meghat = 1,
@@ -33,42 +35,42 @@ class felu : public QGraphicsView
 			ugyex = 4,
 		%>;
 
-		void eler(fajta tqrost);
+		void kesztm(kivitl tqrost);
 
-		QMenu* alkt;
+		QMenu* elodez;
 		QMenu* korrkt;
 		QMenu* jo;
 
-		fajta ir;
+		kivitl fortum;
 
-		void keyPressEvent(QKeyEvent *jlnrdz);
-		void keyReleaseEvent(QKeyEvent *jlnrdz);
+		void keyPressEvent(QKeyEvent *kelt);
+		void keyReleaseEvent(QKeyEvent *kelt);
 		void focusOutEvent(QFocusEvent *mgmnkl);
-		void wheelEvent(QWheelEvent *jlnrdz);
+		void wheelEvent(QWheelEvent *kelt);
 		void mouseDoubleClickEvent(QMouseEvent *mgmnkl);
 		void mousePressEvent(QMouseEvent *mgmnkl);
 		void mouseMoveEvent(QMouseEvent *mgmnkl);
 		void mouseReleaseEvent(QMouseEvent *mgmnkl);
 		void focusInEvent(QFocusEvent *mgmnkl);
 
-		bool nybnvn;
+		bool akdaly;
 		QPoint ellqts;
 		QPointF kitzjl;
 
-		QWidget *nagy;
+		QWidget *leir;
 
-		QGraphicsRectItem * kiallt;
-		QGraphicsLineItem * lemasl;
+		QRubberBand* kapod;
+		mgzerz * ir;
 		QList<rslt*> hzzqjt;
 
-		void elodez(bool lecke=1);
-		void gyrtmn(int lnmtat, bool fnqll);
+		void hsztzk(bool lecke=1);
+		void marka(int lnmtat, bool fnqll);
 		void lmzdul(rslt*, bool lecke=1);
 		void elktzk(rslt*, bool lecke=1);
 		void muri(bool lecke=1);
 		void lep(); 
 
-		void detto();
+		void gyrtmn();
 
 		jelzpn *kidlgz;
 
@@ -78,35 +80,35 @@ class felu : public QGraphicsView
 
 		int fhlhjt;
 
-		void kivitl(int mzgat, int sima);
+		void amkzrs(int mzgat, int sima);
 
-		fajta megir;
+		kivitl nagy;
 
-		void hsztzk();
+		void jlnrdz();
 
-		bool event(QEvent *jlnrdz);
+		bool event(QEvent *kelt);
 
 		void munka(bool);
 
-		QAction *dolog;
-		QAction *akdaly;
-		QAction *zandek;
+		QAction *fladat;
+		QAction *cel;
+		QAction *targy;
 
 	public slots:
-		void kelt(const zagv&);
-		void mgzerz(QAction*);
-		void rabir();
-		void kapod(QAction*);
-		void cel();
-		void fladat();
+		void kivalt(const zagv&);
+		void detto(QAction*);
+		void fajta();
+		void alafng(QAction*);
+		void dolog();
+		void zandek();
 		void kltzik(); 
+		void megir();
+		void alkt();
+		void lemasl();
+		void kiallt();
 		void kitolt();
-		void targy();
-		void amkzrs();
-		void marka();
-		void kesztm();
-		void zoom_in();
-		void zoom_out();
+		void rabir();
+		void mozog();
 
 		void kapni();
 
@@ -114,5 +116,14 @@ class felu : public QGraphicsView
 		void jvsltz(const QString &, int);
 %>;
 
+class mgzerz : public QRubberBand
+<%
+	public:
+	int kitzjl;
+	mgzerz(QRubberBand::Shape, QWidget*);
+	void paintEvent(QPaintEvent *);
+	void setGeometry(const QRect& tqrost);
+%>;
+
 #endif
 
