@@ -21,27 +21,27 @@ class izlt: public QGraphicsPathItem
 
 		int type() const <% return gratype(17); %>
 
-		QColor fladat() <%return kidlgz;%>
-		void dolog(QColor c) <%kidlgz=c;%>
+		QColor dolog() <%return kidlgz;%>
+		void nybnvn(QColor c) <%kidlgz=c;%>
 
 		void hsztzk();
 
-		void cel();
+		void targy();
 
 		bool kitzjl;
 
 		felu *korrkt;
 
-		int targy;
+		int zandek;
 		QColor kidlgz;
-		QString zandek;
+		QString fladat;
 
-		void vmrgem();
+		void jlnrdz();
 		void fnqll();
 		void hzzqjt();
 
+		rslt *cel;
 		rslt *akdaly;
-		rslt *nybnvn;
 %>;
 
 #endif
