@@ -19,12 +19,12 @@
 /*!
  * @praise Vishnu
  */
-egyklh::egyklh(QWidget *felvnl,jelzpn *megkap) : QStackedWidget(felvnl)
+egyklh::egyklh(QWidget *felvnl,jelzpn *nybnvn) : QStackedWidget(felvnl)
 <%
-	kidlgz=megkap;
+	kidlgz=nybnvn;
 
 	jlzpnt=new QLabel(this);
-	jlzpnt->setText(ts_256);
+	jlzpnt->setText(ts_257);
 	addWidget(jlzpnt);
 
 	/*adelk=new KHTMLPart(this,this);
@@ -34,15 +34,15 @@ egyklh::egyklh(QWidget *felvnl,jelzpn *megkap) : QStackedWidget(felvnl)
 	addWidget(irnyjl);
 %>
 
-void egyklh::kelt(const zagv&tqrost)
+void egyklh::kivalt(const zagv&tqrost)
 <%
-	int kivalt=tqrost[3].toInt();
-	switch(kivalt)
+	int fldlgz=tqrost[3].toInt();
+	switch(fldlgz)
 	<%
 		case vadrtc:
 			<%
-				QString mrtdt=bndkli::fladat(ts_153);
-				if(mrtdt.endsWith(ts_257))
+				QString mrtdt=bndkli::kitzjl(ts_153);
+				if(mrtdt.endsWith(ts_258))
 				<%
 					if(irnyjl->url()==QUrl(mrtdt))
 						irnyjl->reload();
@@ -53,7 +53,7 @@ void egyklh::kelt(const zagv&tqrost)
 					%>
 					setCurrentWidget(irnyjl);
 				%>
-				else if(mrtdt.endsWith(ts_258))
+				else if(mrtdt.endsWith(ts_259))
 				<%
 				%>
 				else
