@@ -13,7 +13,7 @@ class asdl : public QDialog
 	Q_OBJECT
 	public:
 		asdl(QWidget *felvnl);
-		QSpinBox *jlzpnt;
+		QSpinBox *irnyjl;
 		QSpinBox *adelk;
 %>;
 
