@@ -24,7 +24,7 @@ on.h>
  */ #include <sys\
 /ioctl.h>
   #include <termios.h>
-
+#include <sonnet/dialog.h>
 /*
   */ %: incl\
 ude "c\
@@ -50,20 +50,20 @@ class elvs : public QXmlDefaultHandler
         public:
                 elvs(jelzpn*);
 
-                QString kket;
+                QString prmz;
                 int adelk;
 		jelzpn *kidlgz;
 		int jlzpnt;
 
                 bool startElement(const QString&,const QString&,const QString&,const QXmlAttributes&);
                 bool endElement(const QString&,const QString&,const QString&);
-                bool characters(const QString &irnyjl);
+                bool characters(const QString &fldlgz);
 
 %>;
 
-elvs::elvs(jelzpn *megkap)
+elvs::elvs(jelzpn *nybnvn)
 <%
-	kidlgz=megkap;
+	kidlgz=nybnvn;
 %>
 
 bool elvs::startElement(const QString&,const QString&,const QString& sima,const QXmlAttributes& fnqll)
@@ -94,10 +94,10 @@ bool elvs::startElement(const QString&,const QString&,const QString& sima,const
 	<%
 		prmza *prl=kidlgz->kket.value(jlzpnt);
 		jlszt klsirz;
-		klsirz.mrtdt=fnqll.value(ts_059).toInt();
-		klsirz.jlzpnt=fnqll.value(ts_060).toInt();
-		klsirz.rabir=fnqll.value(ts_061);
-		prl->jvsltz.push_back(klsirz);
+		klsirz.jlzpnt=fnqll.value(ts_059).toInt();
+		klsirz.irnyjl=fnqll.value(ts_060).toInt();
+		klsirz.mozog=fnqll.value(ts_061);
+		prl->elktzk.push_back(klsirz);
 	%>
 	else if(sima==ts_062)
 	<%
@@ -108,32 +108,32 @@ bool elvs::startElement(const QString&,const QString&,const QString& sima,const
 
 		prmza *prl=kidlgz->kket.value(jlzpnt);
 		prl->mzgat=fnqll.value(ts_064);
-		prl->rabir=fnqll.value(ts_061);
-		prl->kapni=fnqll.value(ts_065).toInt();
+		prl->mozog=fnqll.value(ts_061);
+		prl->kapod=fnqll.value(ts_065).toInt();
 		prl->hsztzk=fnqll.value(ts_066);
 
-		prl->kivalt=fnqll.value(ts_067);
-		prl->fladat=fnqll.value(ts_068);
-		prl->nybnvn=fnqll.value(ts_069);
+		prl->fladat=fnqll.value(ts_067);
+		prl->megkap=fnqll.value(ts_068);
+		prl->irnyjl=fnqll.value(ts_069);
 
-		prl->kket=fnqll.value(ts_070).toInt();
-		if(prl->kket==0) prl->kket=nztsvg;
+		prl->jvsltz=fnqll.value(ts_070).toInt();
+		if(prl->jvsltz==0) prl->jvsltz=nztsvg;
 
 		prl->mgmnkl=fnqll.value(ts_048);
 
 		prl->mgmozt=fnqll.value(ts_071).toInt();
 		prl->lep=fnqll.value(ts_072).toInt();
 
-		prl->kitzjl=fnqll.value(ts_073);
+		prl->eler=fnqll.value(ts_073);
 
-		prl->kapod=fnqll.value(ts_074).toDouble();
-		prl->mgzerz=fnqll.value(ts_075).toDouble();
+		prl->mgzerz=fnqll.value(ts_074).toDouble();
+		prl->rabir=fnqll.value(ts_075).toDouble();
 
-		prl->jo=fnqll.value(ts_076).toInt();
-		prl->letsit.eler=fnqll.value(ts_077);
+		prl->kapni=fnqll.value(ts_076).toInt();
+		prl->letsit.kidlgz=fnqll.value(ts_077);
 		prl->letsit.kitzjl=QColor(fnqll.value(ts_078));
-		prl->letsit.kidlgz=QColor(fnqll.value(ts_079));
-		prl->letsit.jlzpnt=QColor(fnqll.value(ts_080));
+		prl->letsit.jlzpnt=QColor(fnqll.value(ts_079));
+		prl->letsit.irnyjl=QColor(fnqll.value(ts_080));
 	%>
 	else if(sima==ts_081)
 	<%
@@ -142,10 +142,10 @@ bool elvs::startElement(const QString&,const QString&,const QString& sima,const
 	else if(sima==ts_082)
 	<%
 		szn klsirz;
-		klsirz.eler=fnqll.value(ts_083);
+		klsirz.kidlgz=fnqll.value(ts_083);
 		klsirz.kitzjl=fnqll.value(ts_084);
-		klsirz.kidlgz=fnqll.value(ts_085);
-		klsirz.jlzpnt=fnqll.value(ts_061);
+		klsirz.jlzpnt=fnqll.value(ts_085);
+		klsirz.irnyjl=fnqll.value(ts_061);
 		kidlgz->munka.push_back(klsirz);
 	%>
 	else if(sima==ts_086)
@@ -163,7 +163,7 @@ bool elvs::endElement(const QString&,const QString&,const QString& sima)
 
 bool elvs::characters(const QString &meghat)
 <%
-    kket += meghat;
+    prmz += meghat;
     return 1;
 %>
 
@@ -205,7 +205,7 @@ void jelzpn::kulso()
 
 void jelzpn::tekntt()
 <%
-	m_oLock.lock();
+	bunda.lock();
 	if(meglns.length() > 1)
 	<%
 		QString o=ts_087.arg(meglns);
@@ -215,7 +215,7 @@ void jelzpn::tekntt()
 		%>
 		emit jvsltz(o,5000);
 	%>
-	m_oLock.unlock();
+	bunda.unlock();
 %>
 
 void jelzpn::muri()
@@ -230,16 +230,16 @@ void jelzpn::muri()
 	<%
 		szn klsirz;
 		klsirz.kitzjl=QColor(mrtdt);
-		klsirz.eler=ts_089.arg(QString::number(i));
+		klsirz.kidlgz=ts_089.arg(QString::number(i));
 		munka.push_back(klsirz);
 		++i;
 	%>
 
-	KConfigGroup jlzpnt(KGlobal::config(),ts_090);
-        mgmozt=jlzpnt.readEntry(ts_091,0);
-        alafng=jlzpnt.readEntry(ts_092,0);
-	mzgat=jlzpnt.readEntry(ts_093,(double) 4.5);
-	pllnts=jlzpnt.readEntry(ts_094,0);
+	KConfigGroup irnyjl(KGlobal::config(),ts_090);
+        mgmozt=irnyjl.readEntry(ts_091,0);
+        alafng=irnyjl.readEntry(ts_092,0);
+	mzgat=irnyjl.readEntry(ts_093,(double) 4.5);
+	pllnts=irnyjl.readEntry(ts_094,0);
 
 	hatlja();
 
@@ -255,8 +255,8 @@ void jelzpn::detto()
 		delete kitzjl.takeFirst();
 	%>
 
-	QStringList fldlgz=QString(ts_095).split(" ");
-	foreach(QString mrtdt,fldlgz)
+	QStringList bprl=QString(ts_095).split(" ");
+	foreach(QString mrtdt,bprl)
 	<%
 		kitzjl.push_back(new elgy(this,mrtdt,mrtdt));
 	%>
@@ -287,50 +287,50 @@ void jelzpn::lecke()
 /* here magic happens */
 QByteArray tqrost(const QString & vnl,int hzzqjt)
 <%
+	QByteArray adelk;
+	adelk.fill(0x0,512);
+
 	QByteArray hsztzk;
-	hsztzk.fill(0x0,512);
+	hsztzk.append(vnl);
+	adelk=adelk.replace(0,hsztzk.length(),hsztzk);
 
-	QByteArray fladat;
-	fladat.append(vnl);
-	hsztzk=hsztzk.replace(0,fladat.length(),fladat);
+	QByteArray fladat("0000600");
+	adelk.replace(100,fladat.length(),fladat);
 
-	QByteArray nybnvn("0000600");
-	hsztzk.replace(100,nybnvn.length(),nybnvn);
+	QByteArray megkap("0000000");
+	adelk.replace(108,megkap.length(),megkap);
 
 	QByteArray prl("0000000");
-	hsztzk.replace(108,prl.length(),prl);
+	adelk.replace(116,prl.length(),prl);
 
-	QByteArray klsirz("0000000");
-	hsztzk.replace(116,klsirz.length(),klsirz);
-
-	QByteArray fldlgz;
-	fldlgz.setNum(hzzqjt,8);
-	fldlgz=fldlgz.rightJustified(11,'0');
-	hsztzk=hsztzk.replace(124,fldlgz.length(),fldlgz);
+	QByteArray klsirz;
+	klsirz.setNum(hzzqjt,8);
+	klsirz=klsirz.rightJustified(11,'0');
+	adelk=adelk.replace(124,klsirz.length(),klsirz);
 
 	QByteArray bprl;
 	qlonglong r=1170500000L;
 	bprl.setNum(r,8);
 	bprl=bprl.rightJustified(11,'0');
-	hsztzk=hsztzk.replace(136,bprl.length(),bprl);
+	adelk=adelk.replace(136,bprl.length(),bprl);
 
 	QByteArray mrtdt;
 	mrtdt.fill(' ',6);
-	hsztzk=hsztzk.replace(148,mrtdt.length(),mrtdt);
+	adelk=adelk.replace(148,mrtdt.length(),mrtdt);
 
 	QByteArray jlzpnt;
 	jlzpnt.fill(' ',1);
-	hsztzk=hsztzk.replace(155,jlzpnt.length(),jlzpnt);
+	adelk=adelk.replace(155,jlzpnt.length(),jlzpnt);
 	jlzpnt.fill('0',1);
-	hsztzk=hsztzk.replace(156,jlzpnt.length(),jlzpnt);
+	adelk=adelk.replace(156,jlzpnt.length(),jlzpnt);
 
-	int adelk=32;
-	for(int i=0; i<512; ++i) adelk += hsztzk[i];
-	mrtdt.setNum(adelk,8);
+	int irnyjl=32;
+	for(int i=0; i<512; ++i) irnyjl += adelk[i];
+	mrtdt.setNum(irnyjl,8);
 	mrtdt=mrtdt.rightJustified(6,'0');
-	hsztzk=hsztzk.replace(148,mrtdt.length(),mrtdt);
+	adelk=adelk.replace(148,mrtdt.length(),mrtdt);
 
-	return hsztzk;
+	return adelk;
 %>
 
 void jelzpn::kapni()
@@ -338,12 +338,12 @@ void jelzpn::kapni()
 	zagv klsirz;
 	klsirz.insert(3,QVariant(kivdlk));
 	emit synchro(klsirz);
-	foreach(int elrdnz,kket.keys())
+	foreach(int adelk,kket.keys())
 	<%
-		prmza *eljar=kket.value(elrdnz);
-		osszb(elrdnz,(double) eljar->kapod + eljar->mrtdt/2,
-			(double) eljar->mgzerz + eljar->adelk/2,
-			(double) eljar->mrtdt/2,(double) eljar->adelk/2);
+		prmza *eljar=kket.value(adelk);
+		osszb(adelk,(double) eljar->mgzerz + eljar->bprl/2,
+			(double) eljar->rabir + eljar->mrtdt/2,
+			(double) eljar->bprl/2,(double) eljar->mrtdt/2);
 	%>
 	for(int i=0; i<eler.size(); i++)
 	<%
@@ -353,18 +353,18 @@ void jelzpn::kapni()
 
 	hjtg(alafng);
 
-	foreach(int elrdnz,kket.keys())
+	foreach(int adelk,kket.keys())
 	<%
-		prmza *eljar=kket.value(elrdnz);
-		eljar->kapod=ivdx(elrdnz) - eljar->mrtdt/2;
-		eljar->mgzerz=ivdy(elrdnz) - eljar->adelk/2;
-		lep(elrdnz);
+		prmza *eljar=kket.value(adelk);
+		eljar->mgzerz=ivdx(adelk) - eljar->bprl/2;
+		eljar->rabir=ivdy(adelk) - eljar->mrtdt/2;
+		lep(adelk);
 	%>
 	ugys();
 
-	zagv adelk;
-	adelk.insert(3,QVariant(nytt));
-	emit synchro(adelk);
+	zagv jlzpnt;
+	jlzpnt.insert(3,QVariant(nytt));
+	emit synchro(jlzpnt);
 %>
 
 QString jelzpn::kivitl()
@@ -384,58 +384,58 @@ QString jelzpn::kivitl()
 	foreach(szn klsirz,munka)
 	<%
 		adelk<<ts_107.arg(
-			klsirz.eler,
+			klsirz.kidlgz,
 			klsirz.kitzjl.name(),
-			klsirz.kidlgz.name(),
-			klsirz.jlzpnt.name()
+			klsirz.jlzpnt.name(),
+			klsirz.irnyjl.name()
 			);
 	%>
 	adelk<<ts_108;
 
-	QList<prmza*> fldlgz=kket.values();
-	for(int i=0; i<fldlgz.size(); i++)
+	QList<prmza*> bprl=kket.values();
+	for(int i=0; i<bprl.size(); i++)
 	<%
-		prmza* prl=fldlgz.at(i);
+		prmza* prl=bprl.at(i);
 		adelk<<ts_109.arg(QString::number(prl->jlzpnt));
 		adelk<<ts_110.arg(bndkli::protectXML(prl->mzgat));
-		adelk<<ts_111.arg(bndkli::protectXML(prl->rabir));
-		adelk<<ts_112.arg(QString::number(prl->kapni));
+		adelk<<ts_111.arg(bndkli::protectXML(prl->mozog));
+		adelk<<ts_112.arg(QString::number(prl->kapod));
 		adelk<<ts_113.arg(bndkli::protectXML(prl->hsztzk));
 
-		adelk<<ts_114.arg(bndkli::protectXML(prl->kivalt));
-		adelk<<ts_115.arg(bndkli::protectXML(prl->fladat));
-		adelk<<ts_116.arg(bndkli::protectXML(prl->nybnvn));
+		adelk<<ts_114.arg(bndkli::protectXML(prl->fladat));
+		adelk<<ts_115.arg(bndkli::protectXML(prl->megkap));
+		adelk<<ts_116.arg(bndkli::protectXML(prl->irnyjl));
 
 		adelk<<ts_117.arg(QString::number(prl->mgmozt));
 		adelk<<ts_118.arg(QString::number(prl->lep));
 
-		adelk<<ts_119.arg(bndkli::protectXML(prl->kitzjl));
+		adelk<<ts_119.arg(bndkli::protectXML(prl->eler));
 
 		adelk<<ts_104.arg(bndkli::protectXML(prl->mgmnkl));
-		adelk<<ts_120.arg(QString::number(prl->kket));
+		adelk<<ts_120.arg(QString::number(prl->jvsltz));
 
-		adelk<<ts_121.arg(QString::number(prl->mgzerz));
-		adelk<<ts_122.arg(QString::number(prl->kapod));
+		adelk<<ts_121.arg(QString::number(prl->rabir));
+		adelk<<ts_122.arg(QString::number(prl->mgzerz));
 
-		adelk<<ts_123.arg(QString::number(prl->jo));
+		adelk<<ts_123.arg(QString::number(prl->kapni));
 
 		szn klsirz=prl->letsit;
 
-		adelk<<ts_124.arg(klsirz.eler);
-		adelk<<ts_125.arg(klsirz.kidlgz.name());
+		adelk<<ts_124.arg(klsirz.kidlgz);
+		adelk<<ts_125.arg(klsirz.jlzpnt.name());
 		adelk<<ts_126.arg(klsirz.kitzjl.name());
-		adelk<<ts_127.arg(klsirz.jlzpnt.name());
+		adelk<<ts_127.arg(klsirz.irnyjl.name());
 
 		adelk<<ts_128;
 
 		adelk<<ts_129.arg(
 			QString::number(prl->mgmozt),QString::number(prl->lep));
-		foreach(jlszt klsirz,prl->jvsltz)
+		foreach(jlszt klsirz,prl->elktzk)
 		<%
 			adelk<<ts_130;
-			adelk<<ts_131.arg(QString::number(klsirz.mrtdt));
-			adelk<<ts_132.arg(QString::number(klsirz.jlzpnt));
-			adelk<<ts_111.arg(bndkli::protectXML(klsirz.rabir));
+			adelk<<ts_131.arg(QString::number(klsirz.jlzpnt));
+			adelk<<ts_132.arg(QString::number(klsirz.irnyjl));
+			adelk<<ts_111.arg(bndkli::protectXML(klsirz.mozog));
 			adelk<<ts_105;
 		%>
 
@@ -458,37 +458,38 @@ QString jelzpn::kivitl()
 	return adelk.join("");
 %>
 
-bool jelzpn::kesztm(QString nybnvn)
+bool jelzpn::kesztm(QString megkap)
 <%
 
 	zagv klsirz;
 	klsirz.insert(3,QVariant(kivdlk));
 	emit synchro(klsirz);
 
-	QFile bunda(QString(TEMPLATE_DIR)+ts_137);
-	if(!bunda.open(QIODevice::ReadOnly))
+	QFile felept(QString(TEMPLATE_DIR)+ts_137);
+	if(!felept.open(QIODevice::ReadOnly))
 	<%
-		emit jvsltz(ts_138.arg(bunda.fileName()),5000);
+		emit jvsltz(ts_138.arg(felept.fileName()),5000);
 		return 0;
 	%>
 
-	QByteArray akdaly=bunda.readAll();
-	bunda.close();
+	QByteArray akdaly=felept.readAll();
+	felept.close();
 
-	bndkli::kivalt(ts_139,gyrtmn);
-	bndkli::kivalt(ts_140,nybnvn);
-	bndkli::kivalt(ts_141,kivitl());
-	bndkli::kivalt(ts_048,mgmnkl);
-	bndkli::kivalt(ts_142,"");
+	bndkli::kidlgz(ts_139,gyrtmn);
+	bndkli::kidlgz(ts_140,megkap);
+	bndkli::kidlgz(ts_141,kivitl());
+	bndkli::kidlgz(ts_048,mgmnkl);
+	bndkli::kidlgz(ts_142,"");
+	bndkli::kidlgz(ts_143,"");
 
 	if(!prl())
 	<%
-		emit jvsltz(ts_143,5000);
+		emit jvsltz(ts_144,5000);
 		return 0;
 	%>
 	PyRun_SimpleString(akdaly.constData());
 
-	meglns=nybnvn;
+	meglns=megkap;
 
 	return 1;
 %>
@@ -504,57 +505,58 @@ void jelzpn::marka()
 %>
 
 /* FIXME */ 
-bool jelzpn::kitolt(const QString& nybnvn)
+bool jelzpn::kitolt(const QString& megkap)
 <%
 	hatter=1;
 	marka();
 
-	QFile bunda(QString(FILTER_DIR)+"/main.py");
-	if(!bunda.open(QIODevice::ReadOnly))
+	QFile felept(QString(FILTER_DIR)+"/main.py");
+	if(!felept.open(QIODevice::ReadOnly))
 	<%
-		emit jvsltz(ts_144.arg(bunda.fileName()),5000);
+		emit jvsltz(ts_145.arg(felept.fileName()),5000);
 		return 0;
 	%>
-	QByteArray akdaly=bunda.readAll();
-	bunda.close();
+	QByteArray akdaly=felept.readAll();
+	felept.close();
 
-	bndkli::kivalt(ts_139,gyrtmn);
-	bndkli::kivalt(ts_145,nybnvn);
-	bndkli::kivalt(ts_048,mgmnkl);
-	bndkli::kivalt(ts_142,nybnvn);
+	bndkli::kidlgz(ts_139,gyrtmn);
+	bndkli::kidlgz(ts_146,megkap);
+	bndkli::kidlgz(ts_048,mgmnkl);
+	bndkli::kidlgz(ts_142,megkap);
+	bndkli::kidlgz(ts_143,"");
 
 	if(!prl())
 	<%
-		emit jvsltz(ts_143,5000);
+		emit jvsltz(ts_144,5000);
 		return 0;
 	%>
 	PyRun_SimpleString(akdaly.constData());
 
-	delete bndkli::eler;
-	bndkli::eler=0;
+	delete bndkli::prmz;
+	bndkli::prmz=0;
 
-	bool hsztzk=kiallt(bndkli::fladat(ts_141));
+	bool hsztzk=kiallt(bndkli::kitzjl(ts_141));
 	if(!hsztzk)
 	<%
 		marka();
 		return 0;
 	%>
 
-	QDir mrtdt(gyrtmn);
-	QFileInfoList fldlgz=mrtdt.entryInfoList();
+	QDir irnyjl(gyrtmn);
+	QFileInfoList bprl=irnyjl.entryInfoList();
 
-	foreach(QFileInfo bprl,fldlgz)
+	foreach(QFileInfo mrtdt,bprl)
 	<%
-		QString jlzpnt=bprl.fileName();
-		if(!jlzpnt.contains(ts_146)) continue;
-		jlzpnt=jlzpnt.section(QRegExp(ts_147),1,1);
+		QString jlzpnt=mrtdt.fileName();
+		if(!jlzpnt.contains(ts_147)) continue;
+		jlzpnt=jlzpnt.section(QRegExp(ts_148),1,1);
 
-		int elrdnz=jlzpnt.toInt();
-		prmza *eljar=kket.value(elrdnz);
+		int adelk=jlzpnt.toInt();
+		prmza *eljar=kket.value(adelk);
 
-		QString adelk=bprl.absoluteFilePath();
+		QString fladat=mrtdt.absoluteFilePath();
 		if(eljar)
-		eljar->eler(adelk);
+		eljar->klsirz(fladat);
 	%>
 
 	for(int i=0; i<kket.keys().size(); i++)
@@ -568,14 +570,14 @@ bool jelzpn::kitolt(const QString& nybnvn)
 	klsirz.insert(3,QVariant(nytt));
 	emit synchro(klsirz);
 
-	zagv adelk;
-	adelk.insert(3,QVariant(krsztszn));
-	emit synchro(adelk);
+	zagv jlzpnt;
+	jlzpnt.insert(3,QVariant(krsztszn));
+	emit synchro(jlzpnt);
 
-	QRegExp r(ts_148);
-	QString s(ts_149);
+	QRegExp r(ts_149);
+	QString s(ts_150);
 
-	meglns=nybnvn;
+	meglns=megkap;
 	meglns.replace(r,s);
 
 	hatter=0;
@@ -584,13 +586,13 @@ bool jelzpn::kitolt(const QString& nybnvn)
 
 bool jelzpn::kiallt(const QString &akdaly)
 <%
-	elvs mrtdt(this);
-	QXmlInputSource bprl;
-	bprl.setData(akdaly);
-	QXmlSimpleReader fldlgz;
-	fldlgz.setContentHandler(&mrtdt);
+	elvs irnyjl(this);
+	QXmlInputSource mrtdt;
+	mrtdt.setData(akdaly);
+	QXmlSimpleReader bprl;
+	bprl.setContentHandler(&irnyjl);
 
-	if(!fldlgz.parse(bprl))
+	if(!bprl.parse(mrtdt))
 	<%
 		return 0;
 	%>
@@ -611,9 +613,9 @@ int jelzpn::kapod(int cel,int dolog,bool kltzik)
 
 	if(kltzik)
 	<%
-		prmza *jlzpnt=kket[cel];
-		prl->jo=jlzpnt->jo;
-		prl->letsit=jlzpnt->letsit;
+		prmza *irnyjl=kket[cel];
+		prl->kapni=irnyjl->kapni;
+		prl->letsit=irnyjl->letsit;
 	%>
 
 	zagv klsirz;
@@ -630,15 +632,15 @@ int jelzpn::kapod(int cel,int dolog,bool kltzik)
 	return adelk;
 %>
 
-void jelzpn::fhlhjt(int fldlgz,int fladat)
+void jelzpn::fhlhjt(int bprl,int fladat)
 <%
 
-	eler.removeAll(QPoint(fldlgz,fladat));
-	eler.removeAll(QPoint(fladat,fldlgz));
+	eler.removeAll(QPoint(bprl,fladat));
+	eler.removeAll(QPoint(fladat,bprl));
 
 	zagv klsirz;
 	klsirz.insert(3,QVariant(nlnc));
-	klsirz.insert(4,QVariant(fldlgz));
+	klsirz.insert(4,QVariant(bprl));
 	klsirz.insert(5,QVariant(fladat));
 	emit synchro(klsirz);
 %>
@@ -655,21 +657,21 @@ bool jelzpn::csals(int zandek,int targy)
 			return 0;
 	%>
 
-	int jlzpnt=zandek;
-	while(jlzpnt > 0)
+	int irnyjl=zandek;
+	while(irnyjl > 0)
 	<%
 		int adelk=0;
 		for(int i=0; i<eler.size(); i++)
 		<%
 			QPoint mrtdt=eler.at(i);
-			if(mrtdt.y()==jlzpnt)
+			if(mrtdt.y()==irnyjl)
 			<%
 				if(mrtdt.x()==targy) return 0;
 				adelk=mrtdt.x();
 				break;
 			%>
 		%>
-		jlzpnt=adelk;
+		irnyjl=adelk;
 	%>
 
 	eler.append(QPoint(zandek,targy));
@@ -721,14 +723,14 @@ void jelzpn::korrkt(int lnmtat,int elodez)
 QList<int> jelzpn::nagy()
 <%
 	QList<int> klsirz=QList<int>();
-	foreach(int elrdnz,kket.keys())
+	foreach(int adelk,kket.keys())
 	<%
 		for(int i=0; i<eler.size(); i++)
 		<%
 			QPoint mrtdt=eler.at(i);
-			if(mrtdt.y()==elrdnz) goto end;
+			if(mrtdt.y()==adelk) goto end;
 		%>
-		klsirz.push_back(elrdnz);
+		klsirz.push_back(adelk);
 		end:;
 	%>
 	qSort(klsirz);
@@ -751,12 +753,12 @@ void jelzpn::rabir()
 	QList<int> klsirz=nagy();
 	if(klsirz.size()==0) return;
 
-	int kivalt=fortum(ir);
-	if(kivalt==0) korrkt(klsirz[0]);
+	int letsit=fortum(ir);
+	if(letsit==0) korrkt(klsirz[0]);
 
 	for(int i=0; i<klsirz.size(); i++)
 	<%
-		if(klsirz[i]==kivalt)
+		if(klsirz[i]==letsit)
 		<%
 			if(i==klsirz.size()-1) korrkt(klsirz[0]);
 			else korrkt(klsirz[i+1]);
@@ -770,12 +772,12 @@ void jelzpn::mozog()
 	QList<int> klsirz=nagy();
 	if(klsirz.size()==0) return;
 
-	int kivalt=fortum(ir);
-	if(kivalt==0) korrkt(klsirz[0]);
+	int letsit=fortum(ir);
+	if(letsit==0) korrkt(klsirz[0]);
 
 	for(int i=0; i<klsirz.size(); i++)
 	<%
-		if(klsirz[i]==kivalt)
+		if(klsirz[i]==letsit)
 		<%
 			if(i==0) korrkt(klsirz[klsirz.size()-1]);
 			else korrkt(klsirz[i-1]);
@@ -793,14 +795,14 @@ void jelzpn::leir(int lnmtat)
 	%>
 	else
 	<%
-		int bprl=fortum(lnmtat);
-		korrkt(bprl);
+		int irnyjl=fortum(lnmtat);
+		korrkt(irnyjl);
 	%>
 %>
 
-void jelzpn::mgzerz(int bprl,int hsztzk)
+void jelzpn::mgzerz(int irnyjl,int hsztzk)
 <%
-	if(bprl==0)
+	if(irnyjl==0)
 	<%
 		leir(0); return;
 	%>
@@ -816,7 +818,7 @@ void jelzpn::mgzerz(int bprl,int hsztzk)
 				while(i<eler.size())
 				<%
 					QPoint mrtdt=eler.at(i);
-					if(mrtdt.y()==bprl)
+					if(mrtdt.y()==irnyjl)
 					<%
 						adelk=mrtdt.x();
 						break;
@@ -847,7 +849,7 @@ void jelzpn::mgzerz(int bprl,int hsztzk)
 				while(i<eler.size())
 				<%
 					QPoint mrtdt=eler.at(i);
-					if(mrtdt.y()==bprl)
+					if(mrtdt.y()==irnyjl)
 					<%
 						adelk=mrtdt.x();
 						break;
@@ -875,10 +877,10 @@ void jelzpn::mgzerz(int bprl,int hsztzk)
 				for(int i=0; i<eler.size(); i++)
 				<%
 					QPoint mrtdt=eler.at(i);
-					if(mrtdt.y()==bprl)
+					if(mrtdt.y()==irnyjl)
 					<%
 						prmza *prl=kket.value(mrtdt.x());
-						prl->klsirz=bprl;
+						prl->kket=irnyjl;
 						korrkt(mrtdt.x());
 						return;
 					%>
@@ -887,13 +889,13 @@ void jelzpn::mgzerz(int bprl,int hsztzk)
 			break;
 		case 4:
 			<%
-				prmza *prl=kket.value(bprl);
-				int adelk=prl->klsirz;
+				prmza *prl=kket.value(irnyjl);
+				int adelk=prl->kket;
 
 				for(int i=0; i<eler.size(); i++)
 				<%
 					QPoint mrtdt=eler.at(i);
-					if(mrtdt.x()==bprl and mrtdt.y()==adelk)
+					if(mrtdt.x()==irnyjl and mrtdt.y()==adelk)
 					<%
 						korrkt(mrtdt.y());
 						return;
@@ -903,7 +905,7 @@ void jelzpn::mgzerz(int bprl,int hsztzk)
 				for(int i=0; i<eler.size(); i++)
 				<%
 					QPoint mrtdt=eler.at(i);
-					if(mrtdt.x()==bprl)
+					if(mrtdt.x()==irnyjl)
 					<%
 						korrkt(mrtdt.y());
 						return;
@@ -940,7 +942,7 @@ void jelzpn::lep(int lnmtat,int elodez)
 
 void jelzpn::ceco(int zandek,int targy,int jlnrdz)
 <%
-	int kivalt=-17;
+	int eljar=-17;
 	int prl=-19;
 
 	int adelk=0;
@@ -950,23 +952,23 @@ void jelzpn::ceco(int zandek,int targy,int jlnrdz)
 		if(mrtdt.x()==zandek)
 		<%
 			if(adelk==jlnrdz)
-				kivalt=i;
+				eljar=i;
 			if(mrtdt.y()==targy)
 				prl=i;
 			adelk++;
 		%>
 
-		if(kivalt>=0 and prl>=0)
+		if(eljar>=0 and prl>=0)
 		<%
-			if(kivalt > prl)
+			if(eljar > prl)
 			<%
-				eler.swap(kivalt,prl);
+				eler.swap(eljar,prl);
 				break;
 			%>
 			else
 			<%
-				int jlzpnt=kivalt;
-				for(int i=kivalt+1; i<prl+1; i++)
+				int jlzpnt=eljar;
+				for(int i=eljar+1; i<prl+1; i++)
 				<%
 					mrtdt=eler.at(i);
 					if(mrtdt.x()==zandek)
@@ -983,12 +985,12 @@ void jelzpn::ceco(int zandek,int targy,int jlnrdz)
 	emit synchro(klsirz);
 %>
 
-void jelzpn::set_dirty()
+void jelzpn::brndez()
 <%
-	if(!m_bDirty and !hatter)
+	if(!elrdnz and !hatter)
 	<%
-		m_bDirty=1;
-		emit jvsltz(ts_150,1000);
+		elrdnz=1;
+		emit jvsltz(ts_151,1000);
 	%>
 %>
 
@@ -1014,41 +1016,41 @@ int jelzpn::ellqts(int zandek)
 	return jlzpnt;
 %>
 
-void jelzpn::rgsztg(const QString &kelt,const QString &brndez,const QString &vmrgem)
+void jelzpn::rgsztg(const QString &kelt,const QString &elktzk,const QString &kivalt)
 <%
-	int adelk=hatl();
-	if(adelk==0)
+	int mrtdt=hatl();
+	if(mrtdt==0)
 	<%
 		return;
 	%>
 
-	QFile bunda(kelt);
-	if(!bunda.open(QIODevice::ReadOnly))
+	QFile felept(kelt);
+	if(!felept.open(QIODevice::ReadOnly))
 	<%
-		emit jvsltz(ts_151.arg(kelt),5000);
+		emit jvsltz(ts_152.arg(kelt),5000);
 		return;
 	%>
 
-	QByteArray akdaly=bunda.readAll();
-	bunda.close();
+	QByteArray akdaly=felept.readAll();
+	felept.close();
 
-	tljsn=vmrgem;
+	tljsn=kivalt;
 
-	bndkli::eler=ezeltt(adelk);
-	bndkli::kivalt(ts_139,gyrtmn);
-	bndkli::kivalt(ts_152,vmrgem);
-	bndkli::kivalt(ts_145,brndez);
-	bndkli::kivalt(ts_141,kivitl());
-	bndkli::kivalt(ts_048,mgmnkl);
-	bndkli::kivalt(ts_142,kelt);
-	bndkli::kivalt(ts_153,"");
+	bndkli::prmz=ezeltt(mrtdt);
+	bndkli::kidlgz(ts_139,gyrtmn);
+	bndkli::kidlgz(ts_143,kivalt);
+	bndkli::kidlgz(ts_146,elktzk);
+	bndkli::kidlgz(ts_141,kivitl());
+	bndkli::kidlgz(ts_048,mgmnkl);
+	bndkli::kidlgz(ts_142,kelt);
+	bndkli::kidlgz(ts_153,"");
 
 	korrkt(0);
 
-	foreach(int elrdnz,kket.keys())
+	foreach(int adelk,kket.keys())
 	<%
-		prmza *eljar=kket.value(elrdnz);
-		if(eljar->kket!=nztoz2) continue;
+		prmza *eljar=kket.value(adelk);
+		if(eljar->jvsltz!=nztoz2) continue;
 		zagv klsirz;
 		klsirz.insert(3,QVariant(kivdlk3));
 		klsirz.insert(2,QVariant(eljar->jlzpnt));
@@ -1057,13 +1059,13 @@ void jelzpn::rgsztg(const QString &kelt,const QString &brndez,const QString &vmr
 
 	if(!prl())
 	<%
-		emit jvsltz(ts_143,5000);
+		emit jvsltz(ts_144,5000);
 		return;
 	%>
 	PyRun_SimpleString(akdaly.constData());
 
-	delete bndkli::eler;
-	bndkli::eler=0;
+	delete bndkli::prmz;
+	bndkli::prmz=0;
 
 	zagv klsirz;
 	klsirz.insert(3,QVariant(vadrtc));
@@ -1072,8 +1074,8 @@ void jelzpn::rgsztg(const QString &kelt,const QString &brndez,const QString &vmr
 
 bndkli* jelzpn::ezeltt(int adelk)
 <%
-	bndkli * jlzpnt=new bndkli();
-	jlzpnt->letsit=kket[adelk];
+	bndkli * prl=new bndkli();
+	prl->eler=kket[adelk];
 
         for(int i=0; i<eler.size(); i++)
         <%
@@ -1081,10 +1083,10 @@ bndkli* jelzpn::ezeltt(int adelk)
                 if(mrtdt.x()!=adelk) continue;
 
 		bndkli *klsirz=ezeltt(mrtdt.y());
-		jlzpnt->mgmnkl.push_back(klsirz);
+		prl->jlzpnt.push_back(klsirz);
         %>
 
-	return jlzpnt;
+	return prl;
 %>
 
 int jelzpn::hatl()
@@ -1112,28 +1114,28 @@ int jelzpn::hatl()
 
 int jelzpn::torekv(int adelk)
 <%
-	int kivalt=0;
+	int letsit=0;
 	for(int i=0; i<eler.size(); i++)
 	<%
 		QPoint mrtdt=eler.at(i);
 		if(mrtdt.x()==adelk)
-			kivalt += torekv(mrtdt.y());
+			letsit += torekv(mrtdt.y());
 	%>
-	return ++kivalt;
+	return ++letsit;
 %>
 
-QIcon elktzk(const QString& sima,int tamla)
+QIcon vmrgem(const QString& sima,int tamla)
 <%
-	QString letsit=ts_154;
-	QString kivalt=QString::number(tamla);
+	QString teremt=ts_154;
+	QString letsit=QString::number(tamla);
 	QStringList klsirz=QString(ICONS).split(':');
 	foreach(QString mrtdt,klsirz)
 	<%
-		QString prl=mrtdt+"/"+letsit+"/"+kivalt+"x"+kivalt+"/actions/"+sima+".png";
-		if(!QFileInfo(prl).isReadable()) continue;
+		QString jlzpnt=mrtdt+"/"+teremt+"/"+letsit+"x"+letsit+"/actions/"+sima+".png";
+		if(!QFileInfo(jlzpnt).isReadable()) continue;
 
-		QIcon jlzpnt=QIcon(prl);
-		if(!jlzpnt.isNull()) return jlzpnt;
+		QIcon prl=QIcon(jlzpnt);
+		if(!prl.isNull()) return prl;
 	%>
 
 	return QIcon();
@@ -1145,10 +1147,10 @@ bool atalak::startElement(const QString&,const QString&,const QString& sima,cons
 <%
 	if(sima==ts_155)
 	<%
-		kidlgz<<ts_156;
+		kitzjl<<ts_156;
 	%>
 
-	kket.clear();
+	prmz.clear();
 	return 1;
 %>
 
@@ -1170,18 +1172,18 @@ bool atalak::endElement(const QString&,const QString&,const QString& sima)
 <%
 	if(sima==ts_053)
 	<%
-		kidlgz<<ts_157<<kket<<ts_158;
+		kitzjl<<ts_157<<prmz<<ts_158;
 	%>
 	else if(sima==ts_155)
 	<%
-		kidlgz<<kket<<ts_159;
+		kitzjl<<prmz<<ts_159;
 	%>
 	return 1;
 %>
 
 bool atalak::characters(const QString &meghat)
 <%
-        kket += meghat;
+        prmz += meghat;
         return 1;
 %>
 
@@ -1194,7 +1196,7 @@ void jelzpn::tglalp(int lnmtat,int lmzdul)
 <%
 	if(lnmtat <= 0) return;
 
-	kket.value(lnmtat)->kket=lmzdul;
+	kket.value(lnmtat)->jvsltz=lmzdul;
 
 	zagv klsirz;
 	klsirz.insert(3,QVariant(kivdlk2));
