@@ -19,10 +19,10 @@ class atalak : public QXmlDefaultHandler
 
                 bool startElement(const QString&, const QString&, const QString&, const QXmlAttributes&);
                 bool endElement(const QString&, const QString&, const QString&);
-                bool characters(const QString &irnyjl);
+                bool characters(const QString &fldlgz);
 
-                QString kket;
-		QStringList kidlgz;
+                QString prmz;
+		QStringList kitzjl;
 %>;
 
 class prmza;
@@ -48,8 +48,8 @@ class jelzpn: public QObject
 
 		bool hatter;
 
-		void set_dirty();
-		bool m_bDirty;
+		void brndez();
+		bool elrdnz;
 
 		void fajta();
 		void lecke();
@@ -98,7 +98,7 @@ class jelzpn: public QObject
 
 		int lemasl();
 
-		void rgsztg(const QString &kelt, const QString &sima, const QString &vmrgem);
+		void rgsztg(const QString &kelt, const QString &sima, const QString &kivalt);
 
 		int pllnts;
 		int prmz(int lnmtat);
@@ -117,14 +117,14 @@ class jelzpn: public QObject
 		void mgzerz(int, int);
 
 		void tglalp(int lnmtat, int lmzdul);
-		QMutex m_oLock;
+		QMutex bunda;
 
 	public slots:
 		void kapni();
 		void tekntt();
 %>;
 
-QIcon elktzk(const QString& sima, int tamla=32);
+QIcon vmrgem(const QString& sima, int tamla=32);
 
 #endif
 
