@@ -10,8 +10,8 @@ class QCompleter;
 class sblny
 <%
 	public:
-		QRegExp nybnvn;
-		QTextCharFormat kidlgz;
+		QRegExp kitzjl;
+		QTextCharFormat jlzpnt;
 %>;
 
 class nztvh: public QSyntaxHighlighter
@@ -26,19 +26,19 @@ class nztv : public QTextEdit
 <%
 	Q_OBJECT
 	public:
-		nztv(QWidget *felvnl, jelzpn *megkap);
+		nztv(QWidget *felvnl, jelzpn *nybnvn);
 		jelzpn *kidlgz;
 		int jlzpnt;
 		QCompleter *eler;
 		QCompleter *bprl;
-		QCompleter *fldlgz;
+		QCompleter *kket;
 		QAction *fnqll;
 		void keyPressEvent(QKeyEvent*);
 		void kitzjl();
 
 	public slots:
-		void kelt(const zagv&);
-		void nybnvn();
+		void kivalt(const zagv&);
+		void megkap();
 		void prl(const QString &);
 		void lnmtat();
 %>;
