@@ -15,12 +15,12 @@ class oszk : public QWidget
 	public:
 		oszk(QWidget*, jelzpn*);
 		jelzpn *kidlgz;
-		QPixmap prl;
+		QPixmap eler;
 		int jlzpnt;
 
 		void paintEvent(QPaintEvent*);
 
-		QMenu *alkt;
+		QMenu *elodez;
 
 		QAction *kitzjl;
 		QAction *prmz;
@@ -38,8 +38,8 @@ class oszk : public QWidget
 		void jvsltz(const QString&, int);
 
 	public slots:
-		void kelt(const zagv&);
-		void mgmnkl();
+		void kivalt(const zagv&);
+		void vnl();
 		void kket();
 		void bprl(const QPoint&);
 %>;
