@@ -17,61 +17,61 @@ class jelzpn;
 class jlszt 
 <%
 	public:
-	int mrtdt;
 	int jlzpnt;
-	QString rabir;
+	int irnyjl;
+	QString mozog;
 %>;
 
 class jlzlt 
 <%
 	public:
+	QString jlzpnt;
 	QString irnyjl;
-	QString adelk;
 %>;
 
 class prmza 
 <%
 	public:
-		prmza(jelzpn *megkap, int lnmtat);
+		prmza(jelzpn *nybnvn, int lnmtat);
 		jelzpn* kidlgz;
 
 		QString mzgat;
-		QString rabir;
-		int kapni;
+		QString mozog;
+		int kapod;
 		QString hsztzk;
 
-		QString kivalt;
 		QString fladat;
-		QString nybnvn;
+		QString megkap;
+		QString irnyjl;
 
 		QPixmap fnqll;
-		QPixmap dolog;
+		QPixmap cel;
 
 		int jlzpnt;
-		double kapod;
 		double mgzerz;
+		double rabir;
+		double bprl;
 		double mrtdt;
-		double adelk;
 
-		int kket;
+		int jvsltz;
 
 		QList<QString> prmz;
 
-		int jo;
-		int klsirz; 
+		int kapni;
+		int kket; 
 		szn letsit;
 
 		szn& akdaly();
 		szn& felvnl();
 
-		QString kitzjl;
+		QString eler;
 
 		int mgmozt;
 		int lep;
-		QList<jlszt> jvsltz;
+		QList<jlszt> elktzk;
 		QString mgmnkl;
 
-		bool eler(const QString &);
+		bool klsirz(const QString &);
 %>;
 
 #endif
