@@ -15,10 +15,10 @@ class beal : public QDialog
 	Q_OBJECT
 	public:
 		beal(QWidget *felvnl);
-		QComboBox *bprl;
-		QComboBox *prmz;
-		QSpinBox *mrtdt;
-		QPushButton *kitzjl;
+		QComboBox *mrtdt;
+		QComboBox *kitzjl;
+		QSpinBox *lnmtat;
+		QPushButton *fldlgz;
 		QColor kidlgz;
 
 	public slots:
