@@ -35,7 +35,7 @@
 
 QColor rslt::jo  =QColor("#00CCCC");
 QColor rslt::kket=QColor("#ee6060");
-QColor rslt::kapod  =QColor("#FFFCD5");
+QColor rslt::kapni  =QColor("#FFFCD5");
 QColor rslt::mgzerz  =QColor(171,251,199);
 QColor rslt::mzgat=QColor(255,255,255,240);
 
@@ -59,7 +59,7 @@ rslt::rslt(felu *fldlgz,int lnmtat) : QGraphicsRectItem(),korrkt(fldlgz)
 
 	jlzpnt=lnmtat;
 	kitzjl=0;
-	kapni=0;
+	kapod=0;
 	rabir="1";
 
 	mgmozt->setPlainText(korrkt->kidlgz->kket.value(Id())->mzgat);
@@ -70,13 +70,13 @@ rslt::rslt(felu *fldlgz,int lnmtat) : QGraphicsRectItem(),korrkt(fldlgz)
 	setFlags(ItemIsMovable);
 
 	setZValue(100);
-	kidlgz=kapod;
-	eljar=kidlgz;
+	kidlgz=kapni;
+	lep=kidlgz;
 
 	fldlgz->scene()->addItem(this);
 	mozog->hide();
 
-	lep();
+	kltzik();
 %>
 
 bool rslt::moveKey(QKeyEvent* mgmnkl)
@@ -278,28 +278,28 @@ void rslt::keyPressEvent(QKeyEvent* mgmnkl)
 	<%
 		if(meghat->hasSelection())
 		<%
-			const QTextDocumentFragment cel(*meghat);
-			QApplication::clipboard()->setText(cel.toPlainText());
+			const QTextDocumentFragment alkt(*meghat);
+			QApplication::clipboard()->setText(alkt.toPlainText());
 		%>
 	%>
 	else if(mgmnkl==QKeySequence::Cut)
 	<%
 		if(meghat->hasSelection())
 		<%
-			const QTextDocumentFragment cel(*meghat);
-			QApplication::clipboard()->setText(cel.toPlainText());
+			const QTextDocumentFragment alkt(*meghat);
+			QApplication::clipboard()->setText(alkt.toPlainText());
 			meghat->removeSelectedText();
 		%>
 	%>
 	else if(mgmnkl==QKeySequence::Paste)
 	<%
-		const QMimeData *bprl=QApplication::clipboard()->mimeData();
-		if(bprl)
+		const QMimeData *mrtdt=QApplication::clipboard()->mimeData();
+		if(mrtdt)
 		<%
-			QString cel=bprl->text();
-			if(!cel.isNull())
+			QString alkt=mrtdt->text();
+			if(!alkt.isNull())
 			<%
-				meghat->insertFragment(QTextDocumentFragment::fromPlainText(cel));
+				meghat->insertFragment(QTextDocumentFragment::fromPlainText(alkt));
 			%>
 		%>
 	%>
@@ -359,7 +359,7 @@ accept:
 	adjustSize();
 	update();
 
-	kltzik();
+	jvsltz();
 %>
 
 void rslt::keyReleaseEvent(QKeyEvent* mgmnkl)
@@ -371,32 +371,32 @@ void rslt::keyReleaseEvent(QKeyEvent* mgmnkl)
 	%>
 %>
 
-void rslt::jvsltz()
+void rslt::lmzdul()
 <%
 	if(mgmozt->toPlainText()==ts_000) mgmozt->setPlainText("");
-	kapni=1;
-	eljar=kidlgz;
+	kapod=1;
+	lep=kidlgz;
 	kidlgz=mzgat;
 	update();
 %>
 
-void rslt::lmzdul(QFocusEvent *mgmnkl)
+void rslt::elktzk(QFocusEvent *mgmnkl)
 <%
-	if(!kapni) return;
+	if(!kapod) return;
 
-	kidlgz=eljar;
-	kapni=0;
+	kidlgz=lep;
+	kapod=0;
 
 	if(mgmozt->toPlainText().isEmpty()) mgmozt->setPlainText(ts_000);
 
 	prmza *klsirz=korrkt->kidlgz->kket.value(Id());
 	QString mrtdt=mgmozt->toPlainText();
-	if(klsirz->mzgat!=mrtdt) korrkt->kidlgz->set_dirty();
+	if(klsirz->mzgat!=mrtdt) korrkt->kidlgz->brndez();
 	klsirz->mzgat=mrtdt;
 	korrkt->kidlgz->lep(Id(),nztutb);
 
 	adjustSize();
-	kltzik();
+	jvsltz();
 	update();
 %>
 
@@ -408,8 +408,8 @@ void rslt::adjustSize()
 
 	prmza *prl=korrkt->kidlgz->kket.value(Id());
 
-	klsirz.setWidth(felvnl(klsirz.width(),prl->dolog.width()));
-	klsirz.setHeight(klsirz.height() + prl->dolog.height());
+	klsirz.setWidth(irnyjl(klsirz.width(),prl->cel.width()));
+	klsirz.setHeight(klsirz.height() + prl->cel.height());
 
 	klsirz.setWidth(klsirz.width() + 2 * hzzqjt);
 	klsirz.setHeight(klsirz.height() + 2 * hzzqjt + 2.);
@@ -417,9 +417,9 @@ void rslt::adjustSize()
 	setRect(adelk.x(),adelk.y(),klsirz.width(),klsirz.height());
 %>
 
-void rslt::vmrgem(rslt * tqrost)
+void rslt::eljar(rslt * tqrost)
 <%
-	elktzk=tqrost;
+	vmrgem=tqrost;
 %>
 
 void rslt::paint(QPainter *adelk,const QStyleOptionGraphicsItem *option,QWidget * irnyjl)
@@ -429,17 +429,17 @@ void rslt::paint(QPainter *adelk,const QStyleOptionGraphicsItem *option,QWidget
 
 	QPen mrtdt=QPen(Qt::SolidLine);
 
-	mrtdt.setColor(kelt.kidlgz);
+	mrtdt.setColor(kelt.jlzpnt);
 	if(kitzjl) mrtdt.setWidth(2);
 	else mrtdt.setWidth(1);
 
 	adelk->setPen(mrtdt);
 
-	QRectF cel=boundingRect();
+	QRectF alkt=boundingRect();
 	qreal w=mrtdt.width()/2.;
-	QRectF vnl=cel.adjusted(w,w,-w,-w);
+	QRectF vnl=alkt.adjusted(w,w,-w,-w);
 
-	if(korrkt->kidlgz->prmz(Id()) <= 0 and prl->jo > 1)
+	if(korrkt->kidlgz->prmz(Id()) <= 0 and prl->kapni > 1)
 	<%
 		QLinearGradient klsirz(vnl.right()-40,0,vnl.right()-10,0);
 		klsirz.setColorAt(0.,kelt.kitzjl);
@@ -453,11 +453,11 @@ void rslt::paint(QPainter *adelk,const QStyleOptionGraphicsItem *option,QWidget
 		adelk->setBrush(kelt.kitzjl);
 	%>
 
-	if(kapni) adelk->setBrush(QColor(255,255,255));
+	if(kapod) adelk->setBrush(QColor(255,255,255));
 
 	adelk->drawRoundRect(vnl,40,40);
 
-	if(prl->kapni > 0)
+	if(prl->kapod > 0)
 	<%
 		const QPointF points[4] =
 		<%
@@ -465,26 +465,26 @@ void rslt::paint(QPainter *adelk,const QStyleOptionGraphicsItem *option,QWidget
 			vnl.topRight()-QPointF(5,0),
 			vnl.topRight()+QPointF(0,5),
 		%>;
-		adelk->setBrush(kelt.kidlgz);
+		adelk->setBrush(kelt.jlzpnt);
 		adelk->drawPolygon(points,3);
 		adelk->setBrush(kelt.kitzjl);
 	%>
 
-	if(!prl->dolog.isNull())
+	if(!prl->cel.isNull())
 	<%
 		adelk->save();
-		adelk->translate(cel.width()/2 - prl->dolog.width() / 2,hzzqjt);
-		adelk->drawPixmap(0,0,prl->dolog.width(),prl->dolog.height(),prl->fnqll);
+		adelk->translate(alkt.width()/2 - prl->cel.width() / 2,hzzqjt);
+		adelk->drawPixmap(0,0,prl->cel.width(),prl->cel.height(),prl->fnqll);
 		adelk->restore();
 	%>
 
 	adelk->save();
-        adelk->translate(hzzqjt,hzzqjt + prl->dolog.height() + 2.);
+        adelk->translate(hzzqjt,hzzqjt + prl->cel.height() + 2.);
 
 	QAbstractTextDocumentLayout::PaintContext ctx;
 	ctx.palette=QApplication::palette("QTextControl");
 
-	if(kapni)
+	if(kapod)
 	<%
 		ctx.cursorPosition=meghat->position();
 		if(meghat->hasSelection())
@@ -514,7 +514,7 @@ QVariant rslt::itemChange(GraphicsItemChange teremt,const QVariant &letsit)
 
 	if(bprl)
 	<%
-		kltzik();
+		jvsltz();
 	%>
 
 	return mrtdt;
@@ -522,7 +522,7 @@ QVariant rslt::itemChange(GraphicsItemChange teremt,const QVariant &letsit)
 
 bool rslt::hasFocus() const
 <%
-	return kapni;
+	return kapod;
 %>
 
 void rslt::kivalt(izlt* kelt)
@@ -540,30 +540,30 @@ void rslt::hsztzk(izlt* vnl)
 void rslt::elodez()
 <%
 	prmza *prl=korrkt->kidlgz->kket.value(Id());
-	setPos(QPointF(prl->kapod,prl->mgzerz));
+	setPos(QPointF(prl->mgzerz,prl->rabir));
 	mgmozt->setPlainText(prl->mzgat);
 	adjustSize();
+	jvsltz();
 	kltzik();
-	lep();
 %>
 
 void rslt::jlnrdz()
 <%
 	int mrtdt=korrkt->kidlgz->prmz(Id());
-	if(mrtdt < 0) kidlgz=kapod;
+	if(mrtdt < 0) kidlgz=kapni;
 	else kidlgz=mgzerz;
-	eljar=kidlgz;
+	lep=kidlgz;
 %>
 
-void rslt::kltzik()
+void rslt::jvsltz()
 <%
 	foreach(izlt* felvnl,eler)
 	<%
-		felvnl->vmrgem();
+		felvnl->jlnrdz();
 	%>
 %>
 
-void rslt::lep()
+void rslt::kltzik()
 <%
 	prmza *prl=korrkt->kidlgz->kket.value(Id());
 	int bprl=prl->prmz.size() - prmz.size();
@@ -588,8 +588,8 @@ void rslt::lep()
 	for(int i=0; i<prmz.size(); ++i)
 	<%
 		elgyk *klsirz=prmz[i];
-		QPointF cel=QPointF(mrtdt - 25*i - 16,-22);
-		klsirz->setPos(cel);
+		QPointF alkt=QPointF(mrtdt - 25*i - 16,-22);
+		klsirz->setPos(alkt);
 	%>
 %>
 
@@ -602,18 +602,18 @@ rslt::~rslt()
 	delete meghat;
 %>
 
-void rslt::alkt(bool fnqll)
+void rslt::targy(bool fnqll)
 <%
 	kitzjl=fnqll;
 	foreach(izlt* felvnl,eler)
 	<%
-		felvnl->cel();
+		felvnl->targy();
 	%>
 %>
 
 void rslt::inputMethodEvent(QInputMethodEvent *e)
 <%
-	if(!kapni)
+	if(!kapod)
 	<%
 		e->ignore();
 		return;
