@@ -10,9 +10,9 @@ class sbln
 <%
 	public:
 		sbln();
-		QString eler;
-		QString prmz;
 		QString kidlgz;
+		QString kitzjl;
+		QString prmz;
 %>;
 
 #endif
