@@ -12,10 +12,10 @@ class szn
 	public:
 		szn();
 
-		QString eler;
+		QString kidlgz;
 		QColor kitzjl;
-		QColor kidlgz;
 		QColor jlzpnt;
+		QColor irnyjl;
 %>;
 
 #endif
