@@ -23,7 +23,7 @@
 szrt::szrt(felu *fldlgz,rslt *alkt)
 	: QGraphicsEllipseItem(),korrkt(fldlgz)
 <%
-	akdaly=alkt;
+	cel=alkt;
 
 	setZValue(123);
 
@@ -40,12 +40,12 @@ szrt::szrt(felu *fldlgz,rslt *alkt)
 	setBrush(QColor(255,255,0));
 
 	setPos(QPointF(-30,0));
-	setParentItem(akdaly);
+	setParentItem(cel);
 %>
 
 void szrt::paint(QPainter *jlzpnt,const QStyleOptionGraphicsItem *adelk,QWidget * irnyjl)
 <%
         QGraphicsEllipseItem::paint(jlzpnt,adelk,irnyjl);
-        jlzpnt->drawText(boundingRect().translated(0,1),Qt::AlignCenter,akdaly->rabir);
+        jlzpnt->drawText(boundingRect().translated(0,1),Qt::AlignCenter,cel->rabir);
 %>
 
