@@ -18,7 +18,7 @@ class vadrt : public QDialog
 		QLineEdit *jlzpnt;
 		QLineEdit *irnyjl;
 		QLineEdit *adelk;
-		QString lnmtat;
+		QString fldlgz;
 %>;
 
 #endif
