@@ -53,7 +53,7 @@ ude \
 #define zagv QHash<int, QVariant>
 
 qreal adelk(qreal a, qreal b);
-qreal felvnl(qreal a, qreal b);
+qreal irnyjl(qreal a, qreal b);
 
 /* TODO: values hardcoded in some places */
 
