@@ -14,24 +14,24 @@
 /*!
  * @praise Vishnu
  */
-jelzlk::jelzlk(QWidget *felvnl,jelzpn *megkap) : QStackedWidget(felvnl)
+jelzlk::jelzlk(QWidget *felvnl,jelzpn *nybnvn) : QStackedWidget(felvnl)
 <%
-	kidlgz=megkap;
+	kidlgz=nybnvn;
 
 	jlzpnt=new QLabel(this);
 	jlzpnt->setText(ts_160);
 	addWidget(jlzpnt);
 %>
 
-void jelzlk::kelt(const zagv&tqrost)
+void jelzlk::kivalt(const zagv&tqrost)
 <%
-	int kivalt=tqrost[3].toInt();
-	switch(kivalt)
+	int fldlgz=tqrost[3].toInt();
+	switch(fldlgz)
 	<%
 		case vlsztt:
 			<%
-			int bprl=tqrost[2].toInt();
-			if(bprl==0)
+			int irnyjl=tqrost[2].toInt();
+			if(irnyjl==0)
 			<%
 				setCurrentIndex(0);
 				break;
@@ -41,7 +41,7 @@ void jelzlk::kelt(const zagv&tqrost)
 			<%
 			prmza *prl=*kidlgz + tqrost[2].toInt();
 			int j=0;
-			switch(prl->kket)
+			switch(prl->jvsltz)
 			<%
 				case nztoz2: j++;
 				case aljlk: j++;
