@@ -11,12 +11,12 @@ class jelzlk : public QStackedWidget
 <%
 	Q_OBJECT
 	public:
-		jelzlk(QWidget *felvnl, jelzpn *megkap);
+		jelzlk(QWidget *felvnl, jelzpn *nybnvn);
 		jelzpn *kidlgz;
 		QLabel *jlzpnt;
 
 	public slots:
-		void kelt(const zagv&);
+		void kivalt(const zagv&);
 %>;
 
 #endif
