@@ -28,38 +28,38 @@ elgyk::elgyk(felu *fldlgz,rslt *alkt)
 	: QGraphicsRectItem(),korrkt(fldlgz)
 <%
 	setFlags(ItemIsMovable & ItemIsSelectable);
-	letsit=alkt;
+	eler=alkt;
 	setRect(0,0,19,19);
 
 	/* set the z value to 51 */
 	setZValue(51);
 
         fldlgz->scene()->addItem(this);
-	setParentItem(letsit);
+	setParentItem(eler);
 %>
 
-void elgyk::paint(QPainter *adelk,const QStyleOptionGraphicsItem *bprl,QWidget * irnyjl)
+void elgyk::paint(QPainter *adelk,const QStyleOptionGraphicsItem *felvnl,QWidget * irnyjl)
 <%
-	int alafng=0;
-	for(int i=0; i<letsit->prmz.size(); ++i)
+	int rgsztg=0;
+	for(int i=0; i<eler->prmz.size(); ++i)
 	<%
-		if(this==letsit->prmz[i]) <% alafng=i; break; %>
+		if(this==eler->prmz[i]) <% rgsztg=i; break; %>
 	%>
-	prmza *mrtdt=korrkt->kidlgz->kket.value(letsit->Id());
-	QString jlzpnt=mrtdt->prmz[alafng];
+	prmza *mrtdt=korrkt->kidlgz->kket.value(eler->Id());
+	QString jlzpnt=mrtdt->prmz[rgsztg];
 
 	for(int i=0; i<korrkt->kidlgz->kitzjl.size(); ++i)
 	<%
-		if(korrkt->kidlgz->kitzjl[i]->kidlgz==jlzpnt)
+		if(korrkt->kidlgz->kitzjl[i]->kket==jlzpnt)
 		<%
-			QSvgRenderer *klsirz=korrkt->kidlgz->kitzjl[i]->prmz();
+			QSvgRenderer *klsirz=korrkt->kidlgz->kitzjl[i]->bprl();
 			klsirz->render(adelk,boundingRect());
 			break;
 		%>
 	%>
 %>
 
-#if WAF
+#ifdef WAF
 #else
 #include "Flult.moc"
 #endif
