@@ -22,8 +22,8 @@ class elgyk: public QGraphicsRectItem
 
 		int type() const <% return gratype(797); %>
 		felu *korrkt;
-		rslt *letsit;
-		void paint(QPainter *adelk, const QStyleOptionGraphicsItem *bprl, QWidget * irnyjl);
+		rslt *eler;
+		void paint(QPainter *adelk, const QStyleOptionGraphicsItem *felvnl, QWidget * irnyjl);
 %>;
 
 #endif
