@@ -24,7 +24,7 @@ class szrtrd : public QXmlDefaultHandler
         public:
                 szrtrd(dbz*);
 
-                QString kket;
+                QString prmz;
                 int adelk;
 		dbz *kidlgz;
 		izltb *korrkt;
@@ -32,13 +32,13 @@ class szrtrd : public QXmlDefaultHandler
 
                 bool startElement(const QString&, const QString&, const QString&, const QXmlAttributes&);
                 bool endElement(const QString&, const QString&, const QString&);
-                bool characters(const QString &irnyjl);
+                bool characters(const QString &fldlgz);
 
 %>;
 
-szrtrd::szrtrd(dbz *megkap)
+szrtrd::szrtrd(dbz *nybnvn)
 <%
-	kidlgz = megkap;
+	kidlgz = nybnvn;
 %>
 
 bool szrtrd::startElement(const QString&, const QString&, const QString& sima, const QXmlAttributes& fnqll)
@@ -61,19 +61,19 @@ bool szrtrd::startElement(const QString&, const QString&, const QString& sima, c
 		klsirz->elodez = fnqll.value(ts_169).toInt();
 		klsirz->alkt = fnqll.value(ts_170).toInt();
 
-		int kivalt = fnqll.value(ts_075).toInt();
+		int letsit = fnqll.value(ts_075).toInt();
 		foreach (rsltb* prl, kidlgz->kket)
 		<%
-			if (prl->jlzpnt == kivalt)
+			if (prl->jlzpnt == letsit)
 			<%
-				klsirz->elktzk = prl; break;
+				klsirz->vmrgem = prl; break;
 			%>
 		%>
 
-		kivalt = fnqll.value(ts_074).toInt();
+		letsit = fnqll.value(ts_074).toInt();
 		foreach (rsltb* prl, kidlgz->kket)
 		<%
-			if (prl->jlzpnt == kivalt)
+			if (prl->jlzpnt == letsit)
 			<%
 				klsirz->targy = prl; break;
 			%>
@@ -85,7 +85,7 @@ bool szrtrd::startElement(const QString&, const QString&, const QString& sima, c
 		if (mrtdt.style() == Qt::NoPen) mrtdt.setStyle(Qt::SolidLine);
 		klsirz->setPen(mrtdt);
 
-		if (!klsirz->targy or !klsirz->elktzk)
+		if (!klsirz->targy or !klsirz->vmrgem)
 		<%
 			delete klsirz;
 			return 0;
@@ -98,7 +98,7 @@ bool szrtrd::startElement(const QString&, const QString&, const QString& sima, c
 	<%
 		if (korrkt)
 		<%
-			korrkt->kket.append(
+			korrkt->lnmtat.append(
 				QPoint(fnqll.value(ts_174).toInt(), fnqll.value(ts_175).toInt()));
 		%>
 	%>
@@ -110,7 +110,7 @@ bool szrtrd::endElement(const QString&, const QString&, const QString& sima)
 <%
 	if (sima == ts_168)
 	<%
-		if (korrkt) korrkt->vmrgem();
+		if (korrkt) korrkt->jlnrdz();
 		korrkt = 0;
 	%>
 	return 1;
@@ -118,7 +118,7 @@ bool szrtrd::endElement(const QString&, const QString&, const QString& sima)
 
 bool szrtrd::characters(const QString &meghat)
 <%
-        kket += meghat;
+        prmz += meghat;
         return 1;
 %>
 
@@ -127,67 +127,67 @@ int dbz::ellqts()
 	return ++jo;
 %>
 
-dbz::dbz(QWidget *irnyjl, jelzpn *megkap) : QGraphicsView(irnyjl)
+dbz::dbz(QWidget *megkap, jelzpn *nybnvn) : QGraphicsView(megkap)
 <%
-	kidlgz = megkap;
+	kidlgz = nybnvn;
 	jo = 0; 
 	jlzpnt = 0;
 
-	QGraphicsScene *felvnl = new QGraphicsScene(this);
-	felvnl->setSceneRect(-400, -400, 400, 400);
-	setScene(felvnl);
+	QGraphicsScene *irnyjl = new QGraphicsScene(this);
+	irnyjl->setSceneRect(-400, -400, 400, 400);
+	setScene(irnyjl);
 
         setRenderHint(QPainter::Antialiasing);
 
-	akdaly = new QAction(ts_001, this);
-	akdaly->setShortcut(ts_002);
-        connect(akdaly, SIGNAL(triggered()), this, SLOT(cel()));
-	addAction(akdaly);
+	cel = new QAction(ts_001, this);
+	cel->setShortcut(ts_002);
+        connect(cel, SIGNAL(triggered()), this, SLOT(dolog()));
+	addAction(cel);
 
-	dolog = new QAction(ts_176, this);
-	dolog->setShortcut(ts_004);
-        connect(dolog, SIGNAL(triggered()), this, SLOT(fladat()));
-	addAction(dolog);
+	fladat = new QAction(ts_176, this);
+	fladat->setShortcut(ts_004);
+        connect(fladat, SIGNAL(triggered()), this, SLOT(zandek()));
+	addAction(fladat);
 
-	zandek = new QAction(ts_005, this);
-	zandek->setShortcut(ts_006);
-        connect(zandek, SIGNAL(triggered()), this, SLOT(targy()));
-	addAction(zandek);
+	targy = new QAction(ts_005, this);
+	targy->setShortcut(ts_177);
+        connect(targy, SIGNAL(triggered()), this, SLOT(alkt()));
+	addAction(targy);
 
-	ceco = new QAction(ts_177, this);
+	ceco = new QAction(ts_178, this);
         connect(ceco, SIGNAL(triggered()), this, SLOT(csals()));
 	addAction(ceco);
 
-	alkt = new QMenu(this);
-	alkt->addAction(dolog);
-	alkt->addAction(akdaly);
-	alkt->addAction(zandek);
-	alkt->addAction(ceco);
+	elodez = new QMenu(this);
+	elodez->addAction(fladat);
+	elodez->addAction(cel);
+	elodez->addAction(targy);
+	elodez->addAction(ceco);
 
 	QAction *klsirz;
 
-	kapod = alkt->addMenu(ts_178);
+	kapod = elodez->addMenu(ts_179);
 	mgzerz = new QActionGroup(this);
-	klsirz = kapod->addAction(ts_179); connect(klsirz, SIGNAL(triggered()), this, SLOT(rabir())); addAction(klsirz); klsirz->setData(QVariant(1)); mgzerz->addAction(klsirz);
-	klsirz = kapod->addAction(ts_180); connect(klsirz, SIGNAL(triggered()), this, SLOT(rabir())); addAction(klsirz); klsirz->setData(QVariant(2)); mgzerz->addAction(klsirz);
-	klsirz = kapod->addAction(ts_181); connect(klsirz, SIGNAL(triggered()), this, SLOT(rabir())); addAction(klsirz); klsirz->setData(QVariant(3)); mgzerz->addAction(klsirz);
+	klsirz = kapod->addAction(ts_180); connect(klsirz, SIGNAL(triggered()), this, SLOT(rabir())); addAction(klsirz); klsirz->setData(QVariant(1)); mgzerz->addAction(klsirz);
+	klsirz = kapod->addAction(ts_181); connect(klsirz, SIGNAL(triggered()), this, SLOT(rabir())); addAction(klsirz); klsirz->setData(QVariant(2)); mgzerz->addAction(klsirz);
+	klsirz = kapod->addAction(ts_182); connect(klsirz, SIGNAL(triggered()), this, SLOT(rabir())); addAction(klsirz); klsirz->setData(QVariant(3)); mgzerz->addAction(klsirz);
 
-	mozog = alkt->addMenu(ts_182);
+	mozog = elodez->addMenu(ts_183);
 	mzgat = new QActionGroup(this);
-	klsirz = mozog->addAction(ts_183); connect(klsirz, SIGNAL(triggered()), this, SLOT(mgmozt())); addAction(klsirz); klsirz->setData(QVariant(Qt::SolidLine)); mzgat->addAction(klsirz);
-	klsirz = mozog->addAction(ts_184); connect(klsirz, SIGNAL(triggered()), this, SLOT(mgmozt())); addAction(klsirz); klsirz->setData(QVariant(Qt::DotLine)); mzgat->addAction(klsirz);
-	klsirz = mozog->addAction(ts_185); connect(klsirz, SIGNAL(triggered()), this, SLOT(mgmozt())); addAction(klsirz); klsirz->setData(QVariant(Qt::DashLine)); mzgat->addAction(klsirz);
+	klsirz = mozog->addAction(ts_184); connect(klsirz, SIGNAL(triggered()), this, SLOT(mgmozt())); addAction(klsirz); klsirz->setData(QVariant(Qt::SolidLine)); mzgat->addAction(klsirz);
+	klsirz = mozog->addAction(ts_185); connect(klsirz, SIGNAL(triggered()), this, SLOT(mgmozt())); addAction(klsirz); klsirz->setData(QVariant(Qt::DotLine)); mzgat->addAction(klsirz);
+	klsirz = mozog->addAction(ts_186); connect(klsirz, SIGNAL(triggered()), this, SLOT(mgmozt())); addAction(klsirz); klsirz->setData(QVariant(Qt::DashLine)); mzgat->addAction(klsirz);
 
-	dolog->setEnabled(0);
-	zandek->setEnabled(0);
-	akdaly->setEnabled(0);
-	alkt->addSeparator();
+	fladat->setEnabled(0);
+	targy->setEnabled(0);
+	cel->setEnabled(0);
+	elodez->addSeparator();
 	ceco->setEnabled(0);
 
 	kitzjl = QPointF(-100, -100);
 
 	korrkt = 0;
-	nybnvn = 0;
+	akdaly = 0;
 	jvsltz = 0;
 %>
 
@@ -196,14 +196,14 @@ dbz::~dbz()
 
 %>
 
-void dbz::wheelEvent(QWheelEvent *jlnrdz)
+void dbz::wheelEvent(QWheelEvent *kelt)
 <%
-	QPointF klsirz = mapToScene(jlnrdz->pos());
-	qreal mrtdt = pow(2.0, -jlnrdz->delta() / 440.0);
-	qreal adelk = matrix().scale(mrtdt, mrtdt).mapRect(QRectF(0, 0, 1, 1)).width();
+	QPointF klsirz = mapToScene(kelt->pos());
+	qreal irnyjl = pow(2.0, kelt->delta() / 440.0);
+	qreal adelk = matrix().scale(irnyjl, irnyjl).mapRect(QRectF(0, 0, 1, 1)).width();
 	if (adelk < 0.01 or adelk > 1000) return;
-	scale(mrtdt, mrtdt);
-	centerOn(klsirz + mapToScene(viewport()->rect().center()) - mapToScene(jlnrdz->pos()));
+	scale(irnyjl, irnyjl);
+	centerOn(klsirz + mapToScene(viewport()->rect().center()) - mapToScene(kelt->pos()));
 %>
 
 void dbz::mouseDoubleClickEvent(QMouseEvent* mgmnkl)
@@ -229,13 +229,13 @@ void dbz::mouseDoubleClickEvent(QMouseEvent* mgmnkl)
 	lmzdul(klsirz);
 	klsirz->bprl(vmrgem - QPointF(vnl.width()/2, vnl.height()/2));
 
-	hsztzk();
+	jlnrdz();
 %>
 
-void dbz::kelt(const zagv& tqrost)
+void dbz::kivalt(const zagv& tqrost)
 <%
-	int kivalt = tqrost[3].toInt();
-	switch (kivalt)
+	int fldlgz = tqrost[3].toInt();
+	switch (fldlgz)
 	<%
 		case ossz:
 			<%
@@ -246,14 +246,14 @@ void dbz::kelt(const zagv& tqrost)
 
 		case vlsztt:
 			<%
-				int fldlgz = jlzpnt;
-				if (fldlgz)
+				int bprl = jlzpnt;
+				if (bprl)
 				<%
-					prmza *eljar = kidlgz->kket.value(fldlgz);
-					if (eljar != 0 and eljar->kket == nztoz2)
+					prmza *eljar = kidlgz->kket.value(bprl);
+					if (eljar != 0 and eljar->jvsltz == nztoz2)
 					<%
 						if (!kidlgz->hatter)
-							eljar->kitzjl = tljsn();
+							eljar->eler = sima();
 					%>
 				%>
 				kapni();
@@ -264,8 +264,8 @@ void dbz::kelt(const zagv& tqrost)
 				if (jlzpnt)
 				<%
 					prmza *eljar = kidlgz->kket.value(jlzpnt);
-					if (eljar and eljar->kket == nztoz2)
-						tiszta(eljar->kitzjl);
+					if (eljar and eljar->jvsltz == nztoz2)
+						tljsn(eljar->eler);
 				%>
 			%>
 			break;
@@ -273,44 +273,44 @@ void dbz::kelt(const zagv& tqrost)
 			<%
 				if (not jlzpnt) break;
 				prmza *eljar = kidlgz->kket.value(jlzpnt);
-				if (eljar->kket != nztoz2)
+				if (eljar->jvsltz != nztoz2)
 				<%
 					break;
 				%>
-				eljar->kitzjl = tljsn();
+				eljar->eler = sima();
 			%>
 			break;
 		case kivdlk3:
 			<%
-				int fldlgz = jlzpnt;
+				int bprl = jlzpnt;
 				kapni();
 
 				jlzpnt = tqrost[2].toInt();
 				prmza *eljar = kidlgz->kket.value(jlzpnt);
-				tiszta(eljar->kitzjl);
+				tljsn(eljar->eler);
 
 				QRectF vnl = scene()->itemsBoundingRect();
 				vnl = QRectF(vnl.topLeft() - QPointF(25, 25), vnl.bottomRight() + QPointF(25, 25));
 
 				QRectF adelk(0, 0, vnl.width(), vnl.height());
 
-				QImage bprl((int) adelk.width(), (int) adelk.height(), QImage::Format_RGB32);
-				bprl.fill(qRgb(255,255,255));
+				QImage irnyjl((int) adelk.width(), (int) adelk.height(), QImage::Format_RGB32);
+				irnyjl.fill(qRgb(255,255,255));
 
 				QPainter mrtdt;
-				mrtdt.begin(&bprl);
+				mrtdt.begin(&irnyjl);
 				mrtdt.setRenderHints(QPainter::Antialiasing);
 				scene()->render(&mrtdt, adelk, vnl);
 				mrtdt.end();
 
-				bprl.save(QString(kidlgz->gyrtmn + ts_186 +
-					ts_187).arg(QString::number(jlzpnt)));
+				irnyjl.save(QString(kidlgz->gyrtmn + ts_187 +
+					ts_188).arg(QString::number(jlzpnt)));
 				kapni();
-				jlzpnt = fldlgz;
+				jlzpnt = bprl;
 				if (jlzpnt != 0)
 				<%
 					prmza *eljar = kidlgz->kket.value(jlzpnt);
-					tiszta(eljar->kitzjl);
+					tljsn(eljar->eler);
 				%>
 			%>
 			break;
@@ -329,19 +329,19 @@ void dbz::mousePressEvent(QMouseEvent *mgmnkl)
 		<%
 			if (!hzzqjt.contains(prl))
 			<%
-				elodez();
+				hsztzk();
 				lmzdul(prl);
 			%>
 		%>
 		else
 		<%
-			elodez();
+			hsztzk();
 		%>
-		alkt->popup(mgmnkl->globalPos());
+		elodez->popup(mgmnkl->globalPos());
 		return;
 	%>
 
-	nybnvn = 1;
+	akdaly = 1;
 	kitzjl = mapToScene(mgmnkl->pos());
 	vmrgem = mapToScene(mgmnkl->pos());
 
@@ -361,12 +361,12 @@ void dbz::mousePressEvent(QMouseEvent *mgmnkl)
 		<%
 			if (korrkt) return;
 			korrkt = new izltb(this);
-			korrkt->elktzk = vnl;
+			korrkt->vmrgem = vnl;
 			korrkt->targy = 0;
 			korrkt->elodez = izltb::hzzqjt(
 				vnl->rect(), vnl->pos() - kitzjl);
 			korrkt->alkt = 0;
-			korrkt->vmrgem();
+			korrkt->jlnrdz();
 		%>
 		else if (mgmnkl->modifiers() == Qt::ShiftModifier)
 		<%
@@ -377,7 +377,7 @@ void dbz::mousePressEvent(QMouseEvent *mgmnkl)
 		%>
 		else if (!hzzqjt.contains(vnl))
 		<%
-			elodez();
+			hsztzk();
 			lmzdul(vnl);
 		%>
 
@@ -410,50 +410,50 @@ void dbz::mousePressEvent(QMouseEvent *mgmnkl)
 		else if (hzzqjt.contains(felvnl) and hzzqjt.size() == 1)
 		<%
 			bool adelk = 0; 
-			for (int i=1; i<felvnl->lnmtat.size() - 2; ++i)
+			for (int i=1; i<felvnl->vnl.size() - 2; ++i)
 			<%
-				QPointF klsirz = QPointF((felvnl->lnmtat[i].x()+felvnl->lnmtat[i+1].x())/2,
-						(felvnl->lnmtat[i].y()+felvnl->lnmtat[i+1].y())/2);
+				QPointF klsirz = QPointF((felvnl->vnl[i].x()+felvnl->vnl[i+1].x())/2,
+						(felvnl->vnl[i].y()+felvnl->vnl[i+1].y())/2);
 				QPointF mrtdt = mapToScene(mgmnkl->pos());
 				mrtdt.setX(klsirz.x() - mrtdt.x());
 				mrtdt.setY(klsirz.y() - mrtdt.y());
-				qreal kivalt = mrtdt.x() * mrtdt.x() + mrtdt.y() * mrtdt.y();
-				if (kivalt < 100) 
+				qreal letsit = mrtdt.x() * mrtdt.x() + mrtdt.y() * mrtdt.y();
+				if (letsit < 100) 
 				<%
 					adelk = 1;
 					felvnl->eler = i;
-					felvnl->kidlgz = klsirz;
+					felvnl->kket = klsirz;
 					break;
 				%>
 			%>
 
 			if (!adelk)
 			<%
-				elodez();
+				hsztzk();
 				lmzdul(felvnl);
 				felvnl->eler = 0;
 			%>
 		%>
 		else
 		<%
-			elodez();
+			hsztzk();
 			lmzdul(felvnl);
 			felvnl->eler = 0;
 		%>
 	%>
 	else
 	<%
-		elodez();
+		hsztzk();
 	%>
 %>
 
-void dbz::elodez()
+void dbz::hsztzk()
 <%
 	if (hzzqjt.size() == 1)
 	<%
 		QFocusEvent adelk = QFocusEvent(QEvent::FocusOut);
 		if (hzzqjt[0]->type() == gratype(37))
-			((rsltb*) hzzqjt[0])->lmzdul(&adelk);
+			((rsltb*) hzzqjt[0])->elktzk(&adelk);
 	%>
 
 	while (hzzqjt.size() > 0)
@@ -497,19 +497,19 @@ void dbz::mouseMoveEvent(QMouseEvent *mgmnkl)
 <%
 	if (jvsltz)
 	<%
-		QScrollBar *mrtdt = horizontalScrollBar();
+		QScrollBar *irnyjl = horizontalScrollBar();
 		QScrollBar *adelk = verticalScrollBar();
 
 		QPoint klsirz = mgmnkl->pos() - lnmtat;
 
-		mrtdt->setValue(mrtdt->value() + (isRightToLeft() ? klsirz.x() : - klsirz.x()));
+		irnyjl->setValue(irnyjl->value() + (isRightToLeft() ? klsirz.x() : - klsirz.x()));
 		adelk->setValue(adelk->value() - klsirz.y());
 
 		lnmtat = mgmnkl->pos();
 		return;
 	%>
 
-	if (!nybnvn)
+	if (!akdaly)
 	<%
 		return;
 	%>
@@ -521,7 +521,7 @@ void dbz::mouseMoveEvent(QMouseEvent *mgmnkl)
 
 	if (korrkt)
 	<%
-		korrkt->vmrgem();
+		korrkt->jlnrdz();
 	%>
 	else
 	<%
@@ -532,14 +532,14 @@ void dbz::mouseMoveEvent(QMouseEvent *mgmnkl)
 			izltb *felvnl = (izltb*) hzzqjt[0];
 			int i = felvnl->eler;
 
-			QPointF mrtdt((felvnl->kelt[i].x()+felvnl->kelt[i+1].x())/2,
-					(felvnl->kelt[i].y()+felvnl->kelt[i+1].y())/2);
+			QPointF mrtdt((felvnl->kidlgz[i].x()+felvnl->kidlgz[i+1].x())/2,
+					(felvnl->kidlgz[i].y()+felvnl->kidlgz[i+1].y())/2);
 			--i;
 
-			QPointF klsirz = kitzjl - vmrgem + felvnl->kidlgz - mrtdt;
-			felvnl->kket[i].setX((int) klsirz.x());
-			felvnl->kket[i].setY((int) klsirz.y());
-			felvnl->nybnvn(); 
+			QPointF klsirz = kitzjl - vmrgem + felvnl->kket - mrtdt;
+			felvnl->lnmtat[i].setX((int) klsirz.x());
+			felvnl->lnmtat[i].setY((int) klsirz.y());
+			felvnl->akdaly(); 
 			felvnl->update();
 		%>
 		else if (hzzqjt.size() == 1 and hzzqjt[0]->type() == gratype(37) and
@@ -553,8 +553,8 @@ void dbz::mouseMoveEvent(QMouseEvent *mgmnkl)
 
 			foreach (izltb *felvnl, eler)
 			<%
-				if (felvnl->elktzk == prl or felvnl->targy == prl)
-					felvnl->vmrgem();
+				if (felvnl->vmrgem == prl or felvnl->targy == prl)
+					felvnl->jlnrdz();
 			%>
 		%>
 		else
@@ -568,26 +568,26 @@ void dbz::mouseMoveEvent(QMouseEvent *mgmnkl)
 
 				foreach (izltb *felvnl, eler)
 				<%
-					if (felvnl->elktzk == prl or felvnl->targy == prl)
-						felvnl->vmrgem();
+					if (felvnl->vmrgem == prl or felvnl->targy == prl)
+						felvnl->jlnrdz();
 				%>
 			%>
 		%>
 	%>
-	hsztzk();
+	jlnrdz();
 %>
 
 void dbz::mouseReleaseEvent(QMouseEvent *mgmnkl)
 <%
 	if (jvsltz)
 	<%
-		nybnvn = 0;
+		akdaly = 0;
 		jvsltz = 0;
 		viewport()->setCursor(Qt::ArrowCursor);
 		return;
 	%>
 
-	nybnvn = 0;
+	akdaly = 0;
 	if (korrkt)
 	<%
 		rsltb *prl = 0;
@@ -603,10 +603,10 @@ void dbz::mouseReleaseEvent(QMouseEvent *mgmnkl)
 		if (prl)
 		<%
 			if (!korrkt->targy) korrkt->targy = prl;
-			else korrkt->elktzk = prl;
+			else korrkt->vmrgem = prl;
 
 			if (korrkt->elodez != korrkt->alkt or
-				korrkt->elktzk != korrkt->targy)
+				korrkt->vmrgem != korrkt->targy)
 			<%
 				eler.push_back(korrkt);
 				korrkt->update();
@@ -633,13 +633,13 @@ void dbz::focusOutEvent(QFocusEvent *mgmnkl)
 	<%
 		klsirz->setEnabled(0);
 	%>
-	if (alkt->isVisible()) lep();
+	if (elodez->isVisible()) lep();
 
 	delete korrkt;
 	korrkt = 0;
 %>
 
-void dbz::targy()
+void dbz::alkt()
 <%
 	while (hzzqjt.size() > 0)
 	<%
@@ -652,7 +652,7 @@ void dbz::targy()
 		<%
 			foreach (izltb *felvnl, eler)
 			<%
-				if (felvnl->elktzk == klsirz or felvnl->targy == klsirz)
+				if (felvnl->vmrgem == klsirz or felvnl->targy == klsirz)
 				<%
 					scene()->removeItem(felvnl);
 					delete felvnl;
@@ -673,10 +673,10 @@ void dbz::targy()
 
 void dbz::lep()
 <%
-	dolog->setEnabled(hzzqjt.size() <= 1);
-	zandek->setEnabled(hzzqjt.size() >= 1);
+	fladat->setEnabled(hzzqjt.size() <= 1);
+	targy->setEnabled(hzzqjt.size() >= 1);
 	ceco->setEnabled(hzzqjt.size() >= 1);
-	akdaly->setEnabled(hzzqjt.size() == 1 and hzzqjt[0]->type() == gratype(37));
+	cel->setEnabled(hzzqjt.size() == 1 and hzzqjt[0]->type() == gratype(37));
 
 	kapod->setEnabled(hzzqjt.size() >= 1 and hzzqjt[0]->type() == gratype(39));
 	foreach(QAction* klsirz, mgzerz->actions())
@@ -700,7 +700,7 @@ void dbz::kltzik()
 	lep();
 %>
 
-void dbz::fladat()
+void dbz::zandek()
 <%
 	rsltb *klsirz = new rsltb(this);
 	klsirz->setRect(0, 0, 80, 40);
@@ -730,14 +730,14 @@ void dbz::csals()
 
 void dbz::mgmozt()
 <%
-	int kivalt = ((QAction*) QObject::sender())->data().toInt();
+	int letsit = ((QAction*) QObject::sender())->data().toInt();
 	foreach (QGraphicsItem* klsirz, hzzqjt)
 	<%
 		if (klsirz->type() == gratype(39))
 		<%
 			izltb *felvnl = (izltb*) klsirz;
 			QPen mrtdt = felvnl->pen();
-			mrtdt.setStyle((Qt::PenStyle) kivalt);
+			mrtdt.setStyle((Qt::PenStyle) letsit);
 			felvnl->setPen(mrtdt);
 		%>
 	%>
@@ -746,33 +746,33 @@ void dbz::mgmozt()
 
 void dbz::rabir()
 <%
-	int kivalt = ((QAction*) QObject::sender())->data().toInt();
+	int letsit = ((QAction*) QObject::sender())->data().toInt();
 	foreach (QGraphicsItem* klsirz, hzzqjt)
 	<%
 		if (klsirz->type() == gratype(39))
 		<%
 			izltb *felvnl = (izltb*) klsirz;
 			QPen mrtdt = felvnl->pen();
-			mrtdt.setWidth(kivalt);
+			mrtdt.setWidth(letsit);
 			felvnl->setPen(mrtdt);
 		%>
 	%>
 %>
 
-void dbz::cel()
+void dbz::dolog()
 <%
 	if (hzzqjt.size() == 1 and hzzqjt[0]->type() == gratype(37))
 	<%
 		rsltb *klsirz = (rsltb*) hzzqjt[0];
-		if (klsirz->kapni)
+		if (klsirz->kapod)
 		<%
 			QFocusEvent adelk = QFocusEvent(QEvent::FocusOut);
-			klsirz->lmzdul(&adelk);
+			klsirz->elktzk(&adelk);
 			klsirz->update();
 		%>
 		else
 		<%
-			klsirz->jvsltz();
+			klsirz->lmzdul();
 			klsirz->update();
 		%>
 	%>
@@ -786,7 +786,7 @@ void dbz::munka()
 	%>
 %>
 
-void dbz::ugyex()
+void dbz::tiszta()
 <%
 	foreach (QGraphicsItem *prl, hzzqjt)
 	<%
@@ -794,18 +794,18 @@ void dbz::ugyex()
 	%>
 %>
 
-void dbz::tiszta(const QString &meghat)
+void dbz::tljsn(const QString &meghat)
 <%
-	szrtrd mrtdt(this);
-	QXmlInputSource bprl;
-	bprl.setData(meghat);
-	QXmlSimpleReader fldlgz;
-	fldlgz.setContentHandler(&mrtdt);
-	if (!fldlgz.parse(bprl))
+	szrtrd irnyjl(this);
+	QXmlInputSource mrtdt;
+	mrtdt.setData(meghat);
+	QXmlSimpleReader bprl;
+	bprl.setContentHandler(&irnyjl);
+	if (!bprl.parse(mrtdt))
 	<%
 		kapni();
 	%>
-	hsztzk();
+	jlnrdz();
 %>
 
 void dbz::kapni()
@@ -830,15 +830,15 @@ void dbz::kapni()
 	%>
 %>
 
-QString dbz::tljsn()
+QString dbz::sima()
 <%
 	QStringList l;
-	l<<ts_188;
+	l<<ts_189;
 	foreach (rsltb *adelk, kket)
 	<%
-		l<<ts_189.arg(QString::number(adelk->jlzpnt));
+		l<<ts_190.arg(QString::number(adelk->jlzpnt));
 		l<<ts_111.arg(bndkli::protectXML(adelk->mgmozt->toPlainText()));
-		l<<ts_190.arg(
+		l<<ts_191.arg(
 				QString::number(adelk->pos().x()),
 				QString::number(adelk->pos().y()),
 				QString::number(adelk->rect().width()),
@@ -849,83 +849,83 @@ QString dbz::tljsn()
 
 	foreach (izltb *felvnl, eler)
 	<%
-		l<<ts_191.arg(QString::number(felvnl->jlzpnt));
-		l<<ts_192.arg(QString::number(felvnl->elodez));
-		l<<ts_193.arg(QString::number(felvnl->alkt));
-		l<<ts_194.arg(QString::number(felvnl->pen().width()));
-		l<<ts_195.arg(QString::number(felvnl->pen().style()));
+		l<<ts_192.arg(QString::number(felvnl->jlzpnt));
+		l<<ts_193.arg(QString::number(felvnl->elodez));
+		l<<ts_194.arg(QString::number(felvnl->alkt));
+		l<<ts_195.arg(QString::number(felvnl->pen().width()));
+		l<<ts_196.arg(QString::number(felvnl->pen().style()));
 
-		if (felvnl->elktzk and felvnl->targy)
+		if (felvnl->vmrgem and felvnl->targy)
 		<%
-			l<<ts_196.arg(QString::number(felvnl->elktzk->jlzpnt));
-			l<<ts_197.arg(QString::number(felvnl->targy->jlzpnt));
+			l<<ts_197.arg(QString::number(felvnl->vmrgem->jlzpnt));
+			l<<ts_198.arg(QString::number(felvnl->targy->jlzpnt));
 		%>
 		l<<ts_128;
-		for (int i=0; i<felvnl->kket.size(); ++i)
+		for (int i=0; i<felvnl->lnmtat.size(); ++i)
 		<%
-			l<<ts_198.arg(
-				QString::number(felvnl->kket[i].x()),
-				QString::number(felvnl->kket[i].y()));
+			l<<ts_199.arg(
+				QString::number(felvnl->lnmtat[i].x()),
+				QString::number(felvnl->lnmtat[i].y()));
 		%>
-		l<<ts_199;
+		l<<ts_200;
 	%>
 
-	l<<ts_200;
+	l<<ts_201;
 
 	return l.join("");
 %>
 
-void dbz::keyPressEvent(QKeyEvent *jlnrdz)
+void dbz::keyPressEvent(QKeyEvent *kelt)
 <%
 	if (hzzqjt.size() == 1 and hzzqjt[0]->type() == gratype(37))
 	<%
 		rsltb * prl = (rsltb*) hzzqjt[0];
-		if (prl->kapni and jlnrdz->type() == QEvent::KeyPress)
+		if (prl->kapod and kelt->type() == QEvent::KeyPress)
 		<%
 			setCursor(Qt::ArrowCursor);
-			prl->keyPressEvent(jlnrdz);
+			prl->keyPressEvent(kelt);
 		%>
 	%>
 	if (QApplication::keyboardModifiers() & Qt::ControlModifier) setCursor(Qt::CrossCursor);
-	jlnrdz->accept();
+	kelt->accept();
 %>
 
-void dbz::keyReleaseEvent(QKeyEvent *jlnrdz)
+void dbz::keyReleaseEvent(QKeyEvent *kelt)
 <%
 	if (! (QApplication::keyboardModifiers() & Qt::ControlModifier))
 		setCursor(Qt::ArrowCursor);
 
-	jlnrdz->accept();
+	kelt->accept();
 %>
 
-bool dbz::event(QEvent *jlnrdz)
+bool dbz::event(QEvent *kelt)
 <%
-	/*if (jlnrdz->type() == QEvent::ToolTip)
+	/*if (kelt->type() == QEvent::ToolTip)
 	<%
-		QHelpEvent *adelk = static_cast<QHelpEvent*>(jlnrdz);
+		QHelpEvent *adelk = static_cast<QHelpEvent*>(kelt);
 		QGraphicsItem *prl = scene()->itemAt(mapToScene(adelk->pos()));
 		if (prl and prl->type() == gratype(7))
 		<%
 			prmza *klsirz = *kidlgz + ((rslt*) prl)->Id();
-			if (klsirz and klsirz->kapni > 1)
+			if (klsirz and klsirz->kapod > 1)
 			<%
-				QToolTip::showText(adelk->globalPos(), klsirz->rabir);
+				QToolTip::showText(adelk->globalPos(), klsirz->mozog);
 			%>
 		%>
 	%>
-	else*/ if (jlnrdz->type() == QEvent::KeyPress
-		or jlnrdz->type() == QEvent::ShortcutOverride
-		or jlnrdz->type() == QEvent::Shortcut)
+	else*/ if (kelt->type() == QEvent::KeyPress
+		or kelt->type() == QEvent::ShortcutOverride
+		or kelt->type() == QEvent::Shortcut)
 	<%
 		if (hzzqjt.size() == 1 and hzzqjt[0]->type() == gratype(37))
 		<%
 			rsltb *prl = (rsltb*) hzzqjt[0];
-			if (prl->kapni)
+			if (prl->kapod)
 			<%
-				QKeyEvent *klsirz = (QKeyEvent*) jlnrdz;
-				if (akdaly->shortcut().matches(klsirz->key()))
+				QKeyEvent *klsirz = (QKeyEvent*) kelt;
+				if (cel->shortcut().matches(klsirz->key()))
 				<%
-					return QGraphicsView::event(jlnrdz);
+					return QGraphicsView::event(kelt);
 				%>
 
 				keyPressEvent(klsirz);
@@ -933,21 +933,21 @@ bool dbz::event(QEvent *jlnrdz)
 			%>
 		%>
 	%>
-	else if (jlnrdz->type() == QEvent::InputMethod)
+	else if (kelt->type() == QEvent::InputMethod)
 	<%
 		if (hzzqjt.size() == 1 and hzzqjt[0]->type() == gratype(37))
 		<%
 			rsltb * prl = (rsltb*) hzzqjt[0];
-			if (prl->kapni)
+			if (prl->kapod)
 			<%
-				prl->inputMethodEvent((QInputMethodEvent*) jlnrdz);
+				prl->inputMethodEvent((QInputMethodEvent*) kelt);
 			%>
 		%>
 	%>
-	return QGraphicsView::event(jlnrdz);
+	return QGraphicsView::event(kelt);
 %>
 
-void dbz::hsztzk()
+void dbz::jlnrdz()
 <%
 	QWidget *adelk = viewport();
 	QRect vnl = adelk->rect();
