@@ -27,26 +27,26 @@ class izltb : public QGraphicsRectItem
 		int fladat;
 
 		int eler;
-		QPointF kidlgz;
+		QPointF kket;
 
-		rsltb *elktzk;
+		rsltb *vmrgem;
 		rsltb *targy;
 
-		dbz *jlnrdz;
+		dbz *kelt;
 
-		void vmrgem();
+		void jlnrdz();
 
-		void megkap(QPainter *adelk, int vnl, QPointF hsztzk);
+		void nybnvn(QPainter *adelk, int fnqll, QPointF hsztzk);
 
 		bool contains(const QPointF& hsztzk) CONST;
 
 		int jlzpnt;
 
-		QList<QPoint> lnmtat;
-		QList<QPoint> kelt;
-		QList<QPoint> kket; 
+		QList<QPoint> vnl;
+		QList<QPoint> kidlgz;
+		QList<QPoint> lnmtat; 
 
-		void nybnvn();
+		void akdaly();
 
 		static int hzzqjt(const QRectF&, const QPointF&);
 		int tqrost(const QRectF&, int, const QPointF&);
