@@ -20,10 +20,10 @@ class rsltb : public QGraphicsRectItem
 		void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *);
                 QTextDocument *mgmozt;
                 QTextCursor *meghat;
-		bool kapni;
+		bool kapod;
 
-		qreal kapod;
 		qreal mgzerz;
+		qreal rabir;
 
 		void kitzjl(qreal, qreal);
 		void bprl(QPointF hsztzk);
@@ -33,8 +33,8 @@ class rsltb : public QGraphicsRectItem
 
 		dbz *kidlgz;
 
-		void lmzdul(QFocusEvent*);
-		void jvsltz();
+		void elktzk(QFocusEvent*);
+		void lmzdul();
 
 		void keyPressEvent(QKeyEvent* mgmnkl);
 		bool moveKey(QKeyEvent* mgmnkl);
